@@ -23,11 +23,6 @@
 #include <string.h>
 #include <glib.h>
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include "tifiles.h"
 #include "gettext.h"
 #include "export2.h"
 #include "error.h"
@@ -43,7 +38,7 @@
  *
  * Return value: 0 if error has been caught, the error number otherwise (propagation).
  **/
-TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
+TIEXPORT2 int TICALL tifiles_error_get(FileError number, char **message)
 {
 	if (message == NULL)
 	{
@@ -59,7 +54,7 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: memory too low ?"), 
 			NULL);
-	break;
+    break;
 
 	case ERR_FILE_OPEN:
 		*message = g_strconcat(
@@ -67,7 +62,7 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: either the file does not exist, either there is no room."),
 			NULL);
-	break;
+    break;
 
 	case ERR_FILE_CLOSE:
 		*message = g_strconcat(
@@ -75,7 +70,7 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: either the file does not exist, either there is no room."),
 			NULL);
-	break;
+    break;
 
 	case ERR_GROUP_SIZE:
 		*message = g_strconcat(
@@ -83,7 +78,7 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: too many variables/data."),
 			NULL);
-	break;
+    break;
 
 	case ERR_BAD_CALC:
 		*message = g_strconcat(
@@ -91,7 +86,7 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: probably due to a bug, mail to: tilp-users@lists.sf.net."),
 			NULL);
-	break;
+    break;
 
 	case ERR_INVALID_FILE:
 	case ERR_BAD_FILE:
@@ -100,7 +95,7 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: it's probably not a TI formatted file."),
 			NULL);
-	break;
+    break;
 
 	case ERR_FILE_CHECKSUM:
 		*message = g_strconcat(
@@ -108,7 +103,7 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: the file has an incorrect checksum and may be corrupted."),
 			NULL);
-	break;
+    break;
 
 	case ERR_FILE_ZIP:
 		*message = g_strconcat(
@@ -124,7 +119,7 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: the function you attempted to use is not available."),
 			NULL);
-	break;
+		break;
 
 	case ERR_FILE_IO:
 		*message = g_strconcat(
@@ -132,39 +127,14 @@ TIEXPORT2 int TICALL tifiles_error_get(int number, char **message)
 			"\n",
 			_("Cause: file is corrupted or invalid."),
 			NULL);
-	break;
+		break;
 
-	case ERR_INVALID_PARAM:
-		*message = g_strconcat(
-			_("Msg: invalid parameter."),
-			"\n",
-			_("Cause: the program which uses this library is buggy. Fire-up the developer!"),
-			NULL);
-	break;
 
 	default:
 		// propagate error code
 		return number;
+    break;
 	}
 
 	return 0;
 }
-
-/**
- * tifiles_error_free:
- * @message: a message previously allocated by tifiles_error_get()
- *
- * Free the given message string allocated by tifiles_error_get();
- *
- * Return value: 0 if the argument was valid and the message was freed, nonzero otherwise.
- **/
-TIEXPORT2 int TICALL tifiles_error_free(char *message)
-{
-	if (message == NULL)
-	{
-		tifiles_critical("tifiles_error_free(NULL)\n");
-		return ERR_INVALID_PARAM;
-	}
-	g_free(message);
-	return 0;
-}
