@@ -20,7 +20,7 @@
  */
 
 /*
-  This unit contains a TI file independent API
+  This unit contains a TI file independant API
 */
 
 #include <glib.h>
@@ -36,9 +36,6 @@
 #include "filesnsp.h"
 #include "logging.h"
 
-// Whether to print detailed information about FileContent, BackupContent, FlashContent instances throughout their lifecycle.
-//#define TRACE_CONTENT_INSTANCES
-
 /**
  * tifiles_content_create_regular:
  * @model: a calculator model (required).
@@ -53,20 +50,10 @@ TIEXPORT2 FileContent* TICALL tifiles_content_create_regular(CalcModel model)
 
 	if (content != NULL)
 	{
-		if ((unsigned int)model >= CALC_MAX)
-		{
-			tifiles_warning("Invalid calculator model");
-		}
 		content->model = content->model_dst = model;
-		strncpy(content->comment, tifiles_comment_set_single(), sizeof(content->comment) - 1);
-		content->comment[sizeof(content->comment) - 1] = 0;
+		strcpy(content->comment, tifiles_comment_set_single());
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_create_regular: %p", content);
-	tifiles_file_display_regular(content);
-#endif
-
 	return content;
 }
 
@@ -75,16 +62,11 @@ TIEXPORT2 FileContent* TICALL tifiles_content_create_regular(CalcModel model)
  *
  * Free the whole content of a #FileContent structure.
  *
- * Return value: 0.
+ * Return value: none.
  **/
 TIEXPORT2 int TICALL tifiles_content_delete_regular(FileContent *content)
 {
-	unsigned int i;
-
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_delete_regular: %p", content);
-	tifiles_file_display_regular(content);
-#endif
+	int i;
 
 	if (content != NULL)
 	{
@@ -92,7 +74,7 @@ TIEXPORT2 int TICALL tifiles_content_delete_regular(FileContent *content)
 		{
 			VarEntry *entry = content->entries[i];
 
-			if (entry != NULL)
+			if(entry != NULL)
 			{
 				g_free(entry->data);
 				g_free(entry);
@@ -110,7 +92,6 @@ TIEXPORT2 int TICALL tifiles_content_delete_regular(FileContent *content)
 	{
 		tifiles_critical("%s(NULL)", __FUNCTION__);
 	}
-
 	return 0;
 }
 
@@ -124,7 +105,7 @@ TIEXPORT2 int TICALL tifiles_content_delete_regular(FileContent *content)
 TIEXPORT2 FileContent* TICALL tifiles_content_dup_regular(FileContent *content)
 {
 	FileContent *dup = NULL;
-	unsigned int i;
+	int i;
 
 	if (content != NULL)
 	{
@@ -136,22 +117,8 @@ TIEXPORT2 FileContent* TICALL tifiles_content_dup_regular(FileContent *content)
 
 			if (dup->entries != NULL)
 			{
-				for (i = 0; i < content->num_entries; i++)
-				{
+				for (i = 0; i < content->num_entries; i++) 
 					dup->entries[i] = tifiles_ve_dup(content->entries[i]);
-					if (dup->entries[i] == NULL)
-					{
-						tifiles_content_delete_regular(dup);
-						dup = NULL;
-						break;
-					}
-				}
-			}
-			else
-			{
-				dup->num_entries = 0;
-				tifiles_content_delete_regular(dup);
-				dup = NULL;
 			}
 		}
 	}
@@ -159,12 +126,6 @@ TIEXPORT2 FileContent* TICALL tifiles_content_dup_regular(FileContent *content)
 	{
 		tifiles_critical("%s(NULL)", __FUNCTION__);
 	}
-
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_dup_regular: %p", dup);
-	tifiles_file_display_regular(dup);
-#endif
-
 	return dup;
 }
 
@@ -176,7 +137,7 @@ TIEXPORT2 FileContent* TICALL tifiles_content_dup_regular(FileContent *content)
  * Load the single/group file into a FileContent structure.
  *
  * Structure content must be freed with #tifiles_content_delete_regular when
- * no longer used. If an error occurs, the structure content is released for you.
+ * no longer used.
  *
  * Return value: an error code, 0 otherwise.
  **/
@@ -190,26 +151,20 @@ TIEXPORT2 int tifiles_file_read_regular(const char *filename, FileContent *conte
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(tifiles_file_get_model(filename)))
-	{
 		return ti8x_file_read_regular(filename, (Ti8xRegular *)content);
-	}
 	else 
 #endif
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(tifiles_file_get_model(filename)))
-	{
 		return ti9x_file_read_regular(filename, (Ti9xRegular *)content);
-	}
 	else
 #endif
-	if (content->model == CALC_NSPIRE)
-	{
+	if(content->model == CALC_NSPIRE)
 		return tnsp_file_read_regular(filename, (FileContent *)content);
-	}
 	else
-	{
 		return ERR_BAD_CALC;
-	}
+
+	return 0;
 }
 
 /**
@@ -236,42 +191,32 @@ TIEXPORT2 int tifiles_file_write_regular(const char *filename, FileContent *cont
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(content->model))
-	{
 		return ti8x_file_write_regular(filename, (Ti8xRegular *)content, real_fname);
-	}
 	else 
 #endif
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(content->model))
-	{
 		return ti9x_file_write_regular(filename, (Ti9xRegular *)content, real_fname);
-	}
 	else
 #endif
-	if (content->model == CALC_NSPIRE)
-	{
+	if(content->model == CALC_NSPIRE)
 		return tnsp_file_write_regular(filename, (FileContent *)content, real_fname);
-	}
 	else
-	{
 		return ERR_BAD_CALC;
-	}
+
+	return 0;
 }
 
 /**
  * tifiles_file_display_regular:
- * @content: the file content to show, a FileContent pointer.
+ * @content: the file content to show.
  *
- * Display file content information contained in a FileContent structure.
+ * Display file content informations.
  *
  * Return value: an error code, 0 otherwise.
  **/
 TIEXPORT2 int TICALL tifiles_file_display_regular(FileContent *content)
 {
-	unsigned int i;
-	char trans[257];
-	int model_supports_folder = 1;
-
 	if (content == NULL)
 	{
 		tifiles_critical("%s(NULL)", __FUNCTION__);
@@ -280,66 +225,18 @@ TIEXPORT2 int TICALL tifiles_file_display_regular(FileContent *content)
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(content->model))
-	{
-		tifiles_info("FileContent for TI-8x: %p", content);
-		model_supports_folder = 0;
-	}
+		return ti8x_content_display_regular(content);
 	else 
 #endif
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(content->model))
-	{
-		tifiles_info("FileContent for TI-9x: %p", content);
-	}
+		return ti9x_content_display_regular(content);
 	else
 #endif
-	if (content->model == CALC_NSPIRE)
-	{
-		tifiles_info("FileContent for TI-Nspire: %p", content);
-	}
+	if(content->model == CALC_NSPIRE)
+		return tnsp_content_display_regular(content);
 	else
-	{
 		return ERR_BAD_CALC;
-	}
-
-	tifiles_info("Model:             %02X (%u)", content->model, content->model);
-	tifiles_info("Signature:         %s", tifiles_calctype2signature(content->model));
-	tifiles_info("Comment:           %s", content->comment);
-	if (model_supports_folder)
-	{
-		tifiles_info("Default folder:    %s", content->default_folder);
-	}
-	tifiles_info("Number of entries: %u", content->num_entries);
-	tifiles_info("Entries:           %p", content->entries);
-
-	if (content->entries != NULL)
-	{
-		for (i = 0; i < content->num_entries; i++)
-		{
-			VarEntry * ve = content->entries[i];
-			if (ve != NULL)
-			{
-				tifiles_info("Entry #%u %p", i, ve);
-				if (model_supports_folder)
-				{
-					tifiles_info("  folder:      %s", ve->folder);
-				}
-				tifiles_info("  name:        %s", ticonv_varname_to_utf8_sn(content->model, ve->name, trans, sizeof(trans), ve->type));
-				tifiles_info("  type:        %02X (%s)", ve->type, tifiles_vartype2string(content->model, ve->type));
-				tifiles_info("  attr:        %s", tifiles_attribute_to_string(ve->attr));
-				tifiles_info("  version:     %02X (%u)", ve->version, ve->version);
-				tifiles_info("  length:      %04X (%u)", ve->size, ve->size);
-				tifiles_info("  data:        %p", ve->data);
-			}
-			else
-			{
-				tifiles_critical("%s: an entry in content is NULL", __FUNCTION__);
-			}
-		}
-	}
-
-	tifiles_info("Checksum:      %04X (%u)", content->checksum, content->checksum);
-	tifiles_info("Dest model:    %02X (%u)", content->model_dst, content->model_dst);
 
 	return 0;
 }
@@ -358,20 +255,10 @@ TIEXPORT2 BackupContent* TICALL tifiles_content_create_backup(CalcModel model)
 
 	if (content != NULL)
 	{
-		if ((unsigned int)model >= CALC_MAX)
-		{
-			tifiles_warning("Invalid calculator model");
-		}
 		content->model = model;
-		strncpy(content->comment, tifiles_comment_set_backup(), sizeof(content->comment) - 1);
-		content->comment[sizeof(content->comment) - 1] = 0;
+		strcpy(content->comment, tifiles_comment_set_backup());
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_create_backup: %p", content);
-	tifiles_file_display_backup(content);
-#endif
-
 	return content;
 }
 
@@ -384,17 +271,10 @@ TIEXPORT2 BackupContent* TICALL tifiles_content_create_backup(CalcModel model)
  **/
 TIEXPORT2 int TICALL tifiles_content_delete_backup(BackupContent *content)
 {
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_delete_backup: %p", content);
-	tifiles_file_display_backup(content);
-#endif
-
 	if (content != NULL)
 	{
 		if (tifiles_calc_is_ti9x(content->model))
-		{
 			g_free(content->data_part);
-		}
 		else if (tifiles_calc_is_ti8x(content->model))
 		{
 			g_free(content->data_part1);
@@ -435,19 +315,17 @@ TIEXPORT2 int tifiles_file_read_backup(const char *filename, BackupContent *cont
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(tifiles_file_get_model(filename)))
-	{
 		return ti8x_file_read_backup(filename, content);
-	}
 	else
 #endif 
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(tifiles_file_get_model(filename)))
-	{
 		return ti9x_file_read_backup(filename, content);
-	}
 	else
 #endif
 	return ERR_BAD_CALC;
+
+	return 0;
 }
 
 /**
@@ -469,26 +347,24 @@ TIEXPORT2 int tifiles_file_write_backup(const char *filename, BackupContent *con
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(content->model))
-	{
 		return ti8x_file_write_backup(filename, content);
-	}
 	else
 #endif 
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(content->model))
-	{
 		return ti9x_file_write_backup(filename, content);
-	}
 	else
 #endif
 	return ERR_BAD_CALC;
+
+	return 0;
 }
 
 /**
  * tifiles_file_display_backup:
  * @content: the file content to show.
  *
- * Display file content information.
+ * Display file content informations.
  *
  * Return value: an error code, 0 otherwise.
  **/
@@ -502,19 +378,17 @@ TIEXPORT2 int TICALL tifiles_file_display_backup(BackupContent *content)
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(content->model))
-	{
 		return ti8x_content_display_backup(content);
-	}
 	else 
 #endif
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(content->model))
-	{
 		return ti9x_content_display_backup(content);
-	}
 	else
 #endif
 	return ERR_BAD_CALC;
+
+	return 0;
 }
 
 /**
@@ -531,12 +405,8 @@ TIEXPORT2 FlashContent* TICALL tifiles_content_create_flash(CalcModel model)
 
 	if (content != NULL)
 	{
-		if ((unsigned int)model >= CALC_MAX)
-		{
-			tifiles_warning("Invalid calculator model");
-		}
-		content->model = content->model_dst = model;
-		if (tifiles_calc_is_ti9x(content->model))
+		content->model = model;
+		if(tifiles_calc_is_ti9x(content->model))
 		{
 			time_t tt;
 			struct tm *lt;
@@ -553,11 +423,6 @@ TIEXPORT2 FlashContent* TICALL tifiles_content_create_flash(CalcModel model)
 		}
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_create_flash: %p", content);
-	tifiles_file_display_flash(content);
-#endif
-
 	return content;
 }
 
@@ -566,44 +431,41 @@ TIEXPORT2 FlashContent* TICALL tifiles_content_create_flash(CalcModel model)
  *
  * Free the whole content of a #FlashContent structure.
  *
- * Return value: always 0.
+ * Return value: none.
  **/
 TIEXPORT2 int TICALL tifiles_content_delete_flash(FlashContent *content)
 {
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_delete_flash: %p", content);
-	tifiles_file_display_flash(content);
-#endif
-
+	int i;
 	if (content != NULL)
 	{
 #if !defined(DISABLE_TI8X) && !defined(DISABLE_TI9X)
-		FlashContent *ptr;
-		unsigned int i;
-
-		g_free(content->data_part);
-
-		ptr = content->next;
-		while (ptr != NULL)
 		{
-			FlashContent *next = ptr->next;
+			FlashContent *ptr;
 
-			g_free(ptr->data_part);
-			g_free(ptr);
+			g_free(content->data_part);
 
-			for (i = 0; i < content->num_pages; i++)
+			ptr = content->next;
+			while (ptr != NULL) 
 			{
-				g_free(content->pages[i]->data);
-				g_free(content->pages[i]);
+				FlashContent *next = ptr->next;
+
+				g_free(ptr->data_part);
+				g_free(ptr);
+
+				for(i = 0; i < content->num_pages; i++)
+				{
+					g_free(content->pages[i]->data);
+					g_free(content->pages[i]);
+				}
+				g_free(content->pages);
+
+				ptr = next;
 			}
-			g_free(content->pages);
 
-			ptr = next;
+			g_free(content);
 		}
-
-		g_free(content);
 #else
-		return ERR_BAD_CALC;
+	return ERR_BAD_CALC;
 #endif
 	}
 	else
@@ -614,74 +476,6 @@ TIEXPORT2 int TICALL tifiles_content_delete_flash(FlashContent *content)
 	return 0;
 }
 
-/**
- * tifiles_content_dup_flash:
- *
- * Allocates and copies a new FlashContent structure.
- *
- * Return value: none.
- **/
-TIEXPORT2 FlashContent* TICALL tifiles_content_dup_flash(FlashContent *content)
-{
-	FlashContent *dup = NULL;
-	FlashContent *p, *q;
-
-	if (content != NULL)
-	{
-		dup = tifiles_content_create_flash(content->model);
-		if (dup != NULL)
-		{
-			for (p = content, q = dup; p; p = p->next, q = q->next)
-			{
-				memcpy(q, p, sizeof(FlashContent));
-
-				// TI-68k or TI-eZ80 part
-				if (tifiles_calc_is_ti9x(content->model) || ticonv_model_is_tiez80(content->model))
-				{
-					if (p->data_part)
-					{
-						q->data_part = (uint8_t *)g_malloc0(p->data_length+1);
-						memcpy(q->data_part, p->data_part, p->data_length+1);
-					}
-				}
-
-				// TI-Z80 part
-				if (tifiles_calc_is_ti8x(content->model))
-				{
-					unsigned int i;
-
-					// copy pages
-					q->pages = tifiles_fp_create_array(p->num_pages);
-					for (i = 0; i < content->num_pages; i++)
-					{
-						q->pages[i] = (FlashPage *)g_malloc0(sizeof(FlashPage));
-						memcpy(q->pages[i], p->pages[i], sizeof(FlashPage));
-
-						q->pages[i]->data = (uint8_t *) g_malloc0(p->pages[i]->size);
-						memcpy(q->pages[i]->data, p->pages[i]->data, p->pages[i]->size);
-					}
-				}
-
-				if (p->next)
-				{
-					q->next = tifiles_content_create_flash(p->model);
-				}
-			}
-		}
-	}
-	else
-	{
-		tifiles_critical("%s(NULL)", __FUNCTION__);
-	}
-
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_dup_flash: %p", dup);
-	tifiles_file_display_flash(dup);
-#endif
-
-	return dup;
-}
-
 /**
  * tifiles_file_read_flash:
  * @filename: name of FLASH file to open.
@@ -704,26 +498,20 @@ TIEXPORT2 int tifiles_file_read_flash(const char *filename, FlashContent *conten
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(tifiles_file_get_model(filename)))
-	{
 		return ti8x_file_read_flash(filename, content);
-	}
 	else 
 #endif
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(tifiles_file_get_model(filename)) || tifiles_file_is_tib(filename))
-	{
 		return ti9x_file_read_flash(filename, content);
-	}
 	else
 #endif
-	if (content->model == CALC_NSPIRE)
-	{
+	if(content->model == CALC_NSPIRE)
 		return tnsp_file_read_flash(filename, content);
-	}
 	else
-	{
 		return ERR_BAD_CALC;
-	}
+
+	return 0;
 }
 
 /**
@@ -750,19 +538,17 @@ TIEXPORT2 int tifiles_file_write_flash2(const char *filename, FlashContent *cont
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(content->model))
-	{
 		return ti8x_file_write_flash(filename, content, real_fname);
-	}
 	else 
 #endif
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(content->model))
-	{
 		return ti9x_file_write_flash(filename, content, real_fname);
-	}
 	else
 #endif
 	return ERR_BAD_CALC;
+
+	return 0;
 }
 
 /**
@@ -780,11 +566,72 @@ TIEXPORT2 int tifiles_file_write_flash(const char *filename, FlashContent *conte
 	return tifiles_file_write_flash2(filename, content, NULL);
 }
 
+/**
+ * tifiles_content_dup_flash:
+ *
+ * Allocates and copies a new FlashContent structure.
+ *
+ * Return value: none.
+ **/
+TIEXPORT2 FlashContent* TICALL tifiles_content_dup_flash(FlashContent *content)
+{
+	FlashContent *dup = NULL;
+	FlashContent *p, *q;
+
+	if (content != NULL)
+	{
+		dup = tifiles_content_create_flash(content->model);
+		if (dup != NULL)
+		{
+			for(p = content, q = dup; p; p = p->next, q = q->next)
+			{
+				memcpy(q, p, sizeof(FlashContent));
+
+				// TI9x part
+				if(tifiles_calc_is_ti9x(content->model))
+				{
+					if(p->data_part)
+					{
+						q->data_part = (uint8_t *)g_malloc0(p->data_length+1);
+						memcpy(q->data_part, p->data_part, p->data_length+1);
+					}
+				}
+
+				// TI8x part
+				if(tifiles_calc_is_ti8x(content->model))
+				{
+					int i;
+
+					// copy pages
+					q->pages = tifiles_fp_create_array(p->num_pages);
+					for(i = 0; i < content->num_pages; i++)
+					{
+						q->pages[i] = (FlashPage *)g_malloc0(sizeof(FlashPage));
+						memcpy(q->pages[i], p->pages[i], sizeof(FlashPage));
+
+						q->pages[i]->data = (uint8_t *) g_malloc0(p->pages[i]->size);
+						memcpy(q->pages[i]->data, p->pages[i]->data, p->pages[i]->size);
+					}
+				}
+
+				if(p->next)
+					q->next = tifiles_content_create_flash(p->model);
+			}
+		}
+	}
+	else
+	{
+		tifiles_critical("%s(NULL)", __FUNCTION__);
+	}
+
+	return dup;
+}
+
 /**
  * tifiles_file_display_flash:
  * @content: the file content to show.
  *
- * Display file content information.
+ * Display file content informations.
  *
  * Return value: an error code, 0 otherwise.
  **/
@@ -798,19 +645,17 @@ TIEXPORT2 int TICALL tifiles_file_display_flash(FlashContent *content)
 
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(content->model))
-	{
 		return ti8x_content_display_flash(content);
-	}
 	else 
 #endif
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(content->model))
-	{
 		return ti9x_content_display_flash(content);
-	}
 	else
 #endif
 	return ERR_BAD_CALC;
+
+	return 0;
 }
 
 /**
@@ -824,24 +669,20 @@ TIEXPORT2 int TICALL tifiles_file_display_flash(FlashContent *content)
 TIEXPORT2 int TICALL tifiles_file_display(const char *filename)
 {
 	if (tifiles_file_is_tigroup(filename))
-	{
 		return tifiles_file_display_tigroup(filename);
-	}
 #if !defined(DISABLE_TI8X)
 	if (tifiles_calc_is_ti8x(tifiles_file_get_model(filename)))
-	{
 		return ti8x_file_display(filename);
-	}
 	else
 #endif
 #if !defined(DISABLE_TI9X)
 	if (tifiles_calc_is_ti9x(tifiles_file_get_model(filename)))
-	{
 		return ti9x_file_display(filename);
-	}
 	else
 #endif
 	return ERR_BAD_CALC;
+
+	return 0;
 }
 
 /*****************/
@@ -867,13 +708,13 @@ TIEXPORT2 int TICALL tifiles_file_display(const char *filename)
  * This function may be difficult to understand but it avoids to use trees (and
  * linked list) which will require an implementation.
  *
- * Return value: a 2-dimensions allocated integer array. Must be freed with tifiles_free_table_of_entries when
- * no longer used.
+ * Return value: a 2-dimensions allocated integer array. Must be freed when no
+ * longer used.
  **/
-TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, unsigned int *nfolders)
+TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, int *nfolders)
 {
-	unsigned int num_folders = 0;
-	unsigned int i, j;
+	int num_folders = 0;
+	int i, j;
 	char **ptr, *folder_list[32768] = { 0 };
 	int **table;
 
@@ -883,37 +724,31 @@ TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, unsigned i
 		return NULL;
 	}
 
-	if (content->entries != NULL)
+	// determine how many folders we have
+	for (i = 0; i < content->num_entries; i++) 
 	{
-		// determine how many folders we have
-		for (i = 0; i < content->num_entries; i++)
-		{
-			VarEntry *entry = content->entries[i];
+		VarEntry *entry = content->entries[i];
 
-			// scan for an existing folder entry
-			for (ptr = folder_list; *ptr != NULL; ptr++)
+		// scan for an existing folder entry
+		for (ptr = folder_list; *ptr != NULL; ptr++) 
+		{
+			if (!strcmp(*ptr, entry->folder)) 
 			{
-				if (!strcmp(*ptr, entry->folder))
-				{
-					//printf("break: %s\n", entry->folder);
-					break;
-				}
-			}
-			if (*ptr == NULL)
-			{		// add new folder entry
-				folder_list[num_folders] = (char *) g_malloc0(257);
-				//printf("%i: adding '%s'\n", num_folders, entry->folder);
-				strncpy(folder_list[num_folders], entry->folder, sizeof(folder_list[num_folders]) - 1);
-				folder_list[num_folders][sizeof(folder_list[num_folders]) - 1] = 0;
-				folder_list[num_folders + 1] = NULL;
-				num_folders++;
+				//printf("break: %s\n", entry->folder);
+				break;
 			}
 		}
-		if (tifiles_calc_is_ti8x(content->model))
-		{
+		if (*ptr == NULL) 
+		{		// add new folder entry
+			folder_list[num_folders] = (char *) g_malloc0(257);
+			//printf("%i: adding '%s'\n", num_folders, entry->folder);
+			strcpy(folder_list[num_folders], entry->folder);
+			folder_list[num_folders + 1] = NULL;
 			num_folders++;
 		}
 	}
+	if (tifiles_calc_is_ti8x(content->model))
+		num_folders++;
 	if (nfolders != NULL)
 	{
 		*nfolders = num_folders;
@@ -929,13 +764,13 @@ TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, unsigned i
 	{
 		int k;
 
-		for (i = 0, k = 0; i < content->num_entries; i++)
+		for (i = 0, k = 0; i < content->num_entries; i++) 
 		{
 			VarEntry *entry = content->entries[i];
 
-			if (!strcmp(folder_list[j], entry->folder))
+			if (!strcmp(folder_list[j], entry->folder)) 
 			{
-				table[j] = (int *) g_realloc(table[j], (k + 2) * sizeof(int));
+				table[j] = (int *) realloc(table[j], (k + 2) * sizeof(int));
 				table[j][k] = i;
 				//printf("%i %i: adding %i\n", j, k, i); 
 				table[j][k + 1] = -1;
@@ -946,23 +781,7 @@ TIEXPORT2 int** tifiles_create_table_of_entries(FileContent *content, unsigned i
 
 	// g_free( memory
 	for (j = 0; j < num_folders + 1; j++)
-	{
 		g_free(folder_list[j]);
-	}
 
 	return table;
 }
-
-TIEXPORT2 void tifiles_free_table_of_entries(int ** table)
-{
-	if (table != NULL)
-	{
-		int ** ptr = table;
-		while (*ptr != NULL)
-		{
-			g_free(*ptr);
-			ptr++;
-		}
-		g_free(table);
-	}
-}
