@@ -47,7 +47,7 @@
  *
  * Return value: the array or NULL if failed.
  **/
-TIEXPORT2 FileContent** TICALL tifiles_content_create_group(unsigned int n_entries)
+TIEXPORT2 FileContent** TICALL tifiles_content_create_group(int n_entries)
 {
 	return (FileContent **)g_malloc0((n_entries + 1) * sizeof(FileContent *));
 }
@@ -103,7 +103,7 @@ TIEXPORT2 int TICALL tifiles_content_delete_group(FileContent **array)
 TIEXPORT2 int TICALL tifiles_group_contents(FileContent **src_contents, FileContent **dst_content)
 {
 	FileContent *dst;
-	unsigned int i, j, n;
+	int i, j, n;
 
 	if (src_contents == NULL || dst_content == NULL)
 	{
@@ -113,7 +113,7 @@ TIEXPORT2 int TICALL tifiles_group_contents(FileContent **src_contents, FileCont
 
 	for (n = 0; src_contents[n] != NULL; n++)
 	{
-		if (src_contents[n]->model == CALC_NSPIRE)
+		if(src_contents[n]->model == CALC_NSPIRE)
 		{
 			return ERR_BAD_CALC;
 		}
@@ -132,7 +132,7 @@ TIEXPORT2 int TICALL tifiles_group_contents(FileContent **src_contents, FileCont
 	dst->entries = g_malloc0((n + 1) * sizeof(VarEntry*));
 	if (dst->entries == NULL)
 	{
-		g_free(dst);
+		free(dst);
 		return ERR_MALLOC;
 	}
 
@@ -140,7 +140,7 @@ TIEXPORT2 int TICALL tifiles_group_contents(FileContent **src_contents, FileCont
 	{
 		FileContent *src = src_contents[i];
 
-		for (j = 0; j < src->num_entries; j++)
+		for(j = 0; j < src->num_entries; j++)
 			dst->entries[i] = tifiles_ve_dup(src->entries[j]);
 	}
 
@@ -164,7 +164,7 @@ TIEXPORT2 int TICALL tifiles_group_contents(FileContent **src_contents, FileCont
  **/
 TIEXPORT2 int TICALL tifiles_ungroup_content(FileContent *src, FileContent ***dest)
 {
-	unsigned int i;
+	int i;
 	FileContent **dst;
 
 	if (src == NULL || dest == NULL)
@@ -173,17 +173,13 @@ TIEXPORT2 int TICALL tifiles_ungroup_content(FileContent *src, FileContent ***de
 		return ERR_INVALID_FILE;
 	}
 
-	if (src->model == CALC_NSPIRE)
-	{
+	if(src->model == CALC_NSPIRE)
 		return ERR_BAD_CALC;
-	}
 
 	// allocate an array of FileContent structures (NULL terminated)
 	dst = *dest = (FileContent **)g_malloc0((src->num_entries + 1) * sizeof(FileContent *));
 	if (dst == NULL)
-	{
 		return ERR_MALLOC;
-	}
 
 	// parse each entry and duplicate it into a single content
 	for (i = 0; i < src->num_entries; i++)
@@ -193,9 +189,7 @@ TIEXPORT2 int TICALL tifiles_ungroup_content(FileContent *src, FileContent ***de
 		// allocate and duplicate content
 		dst[i] = (FileContent *)g_malloc0(sizeof(FileContent));
 		if (dst[i] == NULL)
-		{
 			return ERR_MALLOC;
-		}
 		memcpy(dst[i], src, sizeof(FileContent));
 
 		// allocate and duplicate entry
@@ -238,66 +232,43 @@ TIEXPORT2 int TICALL tifiles_group_files(char **src_filenames, const char *dst_f
 		return ERR_INVALID_FILE;
 	}
 
-	// count number of files to group, while performing several checks
-	for (n = 0; src_filenames[n] != NULL; n++)
-	{
-		if (!tifiles_file_is_ti(src_filenames[n]))
-		{
-			return ERR_INVALID_FILE;
-		}
-		if (tifiles_file_get_model(src_filenames[n]) == CALC_NSPIRE)
-		{
-			return ERR_BAD_CALC;
-		}
-	}
+	if(tifiles_file_get_model(src_filenames[0]) == CALC_NSPIRE)
+		return ERR_BAD_CALC;
+
+	// counter number of files to group
+	for (n = 0; src_filenames[n] != NULL; n++);
 
 	// allocate space for that
 	src = (FileContent **)g_malloc0((n + 1) * sizeof(FileContent *));
 	if (src == NULL)
-	{
 		return ERR_MALLOC;
-	}
 
 	// allocate each structure and load file content
 	for (i = 0; i < n; i++)
 	{
 		src[i] = (FileContent *)g_malloc0(sizeof(FileContent));
 		if (src[i] == NULL)
-		{
-			ret = ERR_MALLOC;
-			goto tgf2;
-		}
+			return ERR_MALLOC;
 
 		ret = tifiles_file_read_regular(src_filenames[i], src[i]);
-		if (ret)
-		{
-			goto tgf2;
-		}
+		if(ret) goto tgf;
 	}
 	src[i] = NULL;
 
 	// group the array of structures
 	ret = tifiles_group_contents(src, &dst);
-	if (ret)
-	{
-		goto tgf;
-	}
+	if(ret) goto tgf;
 
 	// write grouped file
 	ret = tifiles_file_write_regular(dst_filename, dst, NULL);
-	if (ret)
-	{
-		goto tgf;
-	}
+	if(ret) goto tgf;
 
-	ret = 0;
 	// release allocated memory
 tgf:
-	tifiles_content_delete_regular(dst);
-tgf2:
 	tifiles_content_delete_group(src);
+	tifiles_content_delete_regular(dst);
 
-	return ret;
+	return 0;
 }
 
 /**
@@ -328,70 +299,49 @@ TIEXPORT2 int TICALL tifiles_ungroup_file(const char *src_filename, char ***dst_
 		return ERR_INVALID_FILE;
 	}
 
-	if (tifiles_file_get_model(src_filename) == CALC_NSPIRE)
-	{
+	if(tifiles_file_get_model(src_filename) == CALC_NSPIRE)
 		return ERR_BAD_CALC;
-	}
 
 	// read group file
 	src = tifiles_content_create_regular(CALC_NONE);
 	ret = tifiles_file_read_regular(src_filename, src);
-	if (ret)
-	{
-		goto tuf3;
-	}
+	if(ret) goto tuf;
 
 	// ungroup structure
 	ret = tifiles_ungroup_content(src, &dst);
-	if (ret)
-	{
-		goto tuf2;
-	}
+	if(ret) goto tuf;
 
 	// count number of structures and allocates array of strings
-	for (ptr = dst, n = 0; *ptr != NULL; ptr++, n++);
-	if (dst_filenames != NULL)
-	{
-		*dst_filenames = (char **)g_malloc0((n + 1) * sizeof(char *));
-	}
+	for(ptr = dst, n = 0; *ptr != NULL; ptr++, n++);
+	if(dst_filenames != NULL)
+		*dst_filenames = (char **)g_malloc((n + 1) * sizeof(char *));
 
 	// store each structure content to file
 	for (ptr = dst, i = 0; *ptr != NULL; ptr++, i++)
 	{
 		ret = tifiles_file_write_regular(NULL, *ptr, &real_name);
-		if (ret)
-		{
-			goto tuf;
-		}
+		if(ret) goto tuf;
 
-		if (dst_filenames != NULL)
-		{
-			(*dst_filenames)[i] = real_name;
-		}
+		if(dst_filenames != NULL)
+			*dst_filenames[i] = real_name;
 		else
-		{
 			g_free(real_name);
-		}
 	}
 
-	ret = 0;
-	goto tuf2;
-
-tuf:
-	if (dst_filenames != NULL)
-	{
-		for (p = *dst_filenames; *p; p++)
-		{
-			g_free(*p);
-		}
-		g_free(*dst_filenames);
-		*dst_filenames = NULL;
-	}
-
-tuf2:
 	// release allocated memory
 	tifiles_content_delete_regular(src);
-tuf3:
+	tifiles_content_delete_group(dst);
+
+	return 0;
+
+tuf:
+	if(dst_filenames != NULL)
+	{
+		for(p = *dst_filenames; *p; p++)
+			g_free(*p);
+		g_free(p);
+	}
+	tifiles_content_delete_regular(src);
 	tifiles_content_delete_group(dst);
 	return ret;
 }
@@ -439,7 +389,7 @@ TIEXPORT2 int TICALL tifiles_content_add_entry(FileContent *content, VarEntry *v
  **/
 TIEXPORT2 int TICALL tifiles_content_del_entry(FileContent *content, VarEntry *ve)
 {
-	unsigned int i, j;
+	int i, j;
 
 	if (content != NULL)
 	{
@@ -450,30 +400,24 @@ TIEXPORT2 int TICALL tifiles_content_del_entry(FileContent *content, VarEntry *v
 		}
 
 		// Search for entry
-		for (i = 0; i < content->num_entries; i++)
+		for(i = 0; i < content->num_entries; i++)
 		{
 			VarEntry *s = content->entries[i];
 
-			if (!strcmp(s->folder, ve->folder) && !strcmp(s->name, ve->name))
-			{
+			if(!strcmp(s->folder, ve->folder) && !strcmp(s->name, ve->name))
 				break;
-			}
 		}
 
 		// Not found ? Exit !
-		if (i == content->num_entries)
-		{
+		if(i == content->num_entries)
 			return -1;
-		}
 
 		// Release
 		tifiles_ve_delete(content->entries[i]);
 
 		// And shift
-		for (j = i; j < content->num_entries; j++)
-		{
+		for(j = i; j < content->num_entries; j++)
 			content->entries[j] = content->entries[j+1];
-		}
 		content->entries[j] = NULL;
 
 		// And resize
@@ -504,7 +448,7 @@ TIEXPORT2 int TICALL tifiles_group_add_file(const char *src_filename, const char
 	CalcModel dst_model;
 	FileContent* src_content = NULL;
 	FileContent* dst_content = NULL;
-	unsigned int i;
+	int i;
 	int ret = 0;
 
 	if (src_filename == NULL || dst_filename == NULL)
@@ -514,10 +458,8 @@ TIEXPORT2 int TICALL tifiles_group_add_file(const char *src_filename, const char
 	}
 
 	// src can be single/group file and dst must be group file
-	if (!tifiles_file_is_group(dst_filename))
-	{
+	if(!tifiles_file_is_group(dst_filename))
 		return -1;
-	}
 
 	src_model = tifiles_file_get_model(src_filename);
 	dst_model = tifiles_file_get_model(dst_filename);
@@ -526,27 +468,19 @@ TIEXPORT2 int TICALL tifiles_group_add_file(const char *src_filename, const char
 	dst_content = tifiles_content_create_regular(dst_model);
 
 	ret = tifiles_file_read_regular(src_filename, src_content);
-	if (!ret)
-	{
-		ret = tifiles_file_read_regular(dst_filename, dst_content);
-		if (!ret)
-		{
-			for (i = 0; i < src_content->num_entries; i++)
-			{
-				tifiles_content_add_entry(dst_content, tifiles_ve_dup(src_content->entries[i]));
-			}
+	if(ret) goto tgaf;
+	ret = tifiles_file_read_regular(dst_filename, dst_content);
+	if(ret) goto tgaf;
 
-			ret = tifiles_file_write_regular(dst_filename, dst_content, NULL);
+	for(i = 0; i < src_content->num_entries; i++)
+		tifiles_content_add_entry(dst_content, tifiles_ve_dup(src_content->entries[i]));
 
-			tifiles_content_delete_regular(dst_content);
-		}
+	ret = tifiles_file_write_regular(dst_filename, dst_content, NULL);
+	if(ret) goto tgaf;
 
-		tifiles_content_delete_regular(src_content);
-	}
-	else
-	{
-		tifiles_content_delete_regular(dst_content);
-	}
+tgaf:
+	tifiles_content_delete_regular(src_content);
+	tifiles_content_delete_regular(dst_content);
 
 	return ret;
 }
@@ -573,23 +507,21 @@ TIEXPORT2 int TICALL tifiles_group_del_file(VarEntry *entry, const char *dst_fil
 	}
 
 	// src can be single/group file and dst must be group file
-	if (!tifiles_file_is_group(dst_filename))
-	{
+	if(!tifiles_file_is_group(dst_filename))
 		return -1;
-	}
 
 	dst_model = tifiles_file_get_model(dst_filename);
 	dst_content = tifiles_content_create_regular(dst_model);
 	ret = tifiles_file_read_regular(dst_filename, dst_content);
-	if (!ret)
-	{
-		tifiles_content_del_entry(dst_content, entry);
-		tifiles_file_display_regular(dst_content);
+	if(ret) goto tgdf;
 
-		ret = tifiles_file_write_regular(dst_filename, dst_content, NULL);
+	tifiles_content_del_entry(dst_content, entry);
+	tifiles_file_display_regular(dst_content);
 
-		tifiles_content_delete_regular(dst_content);
-	}
+	ret = tifiles_file_write_regular(dst_filename, dst_content, NULL);
+	if(ret) goto tgdf;
 
+tgdf:
+	tifiles_content_delete_regular(dst_content);
 	return ret;
 }
