@@ -59,28 +59,26 @@ TIEXPORT2 int TICALL tifiles_library_init()
 	char locale_dir[65536];
 	
 #ifdef __WIN32__
-	HANDLE hDll;
-	int i;
+  	HANDLE hDll;
+  	int i;
+  	
+	hDll = GetModuleHandle("libtifiles2-8.dll");
+  	GetModuleFileName(hDll, locale_dir, 65535);
 
-	hDll = GetModuleHandle("libtifiles2-10.dll");
-	GetModuleFileName(hDll, locale_dir, 65535);
-
-	for (i = strlen(locale_dir); i >= 0; i--)
+  	for (i = strlen(locale_dir); i >= 0; i--) 
 	{
-		if (locale_dir[i] == '\\')
-		{
-			break;
-		}
-	}
-	locale_dir[i] = '\0';
+    		if (locale_dir[i] == '\\')
+      			break;
+  	}  	
+  	locale_dir[i] = '\0';
 
 #ifdef __MINGW32__
-	strcat(locale_dir, "\\..\\share\\locale");
+   strcat(locale_dir, "\\..\\share\\locale");
 #else
-	strcat(locale_dir, "\\locale");
+   strcat(locale_dir, "\\locale");
 #endif
 #else
-	strncpy(locale_dir, LOCALEDIR, sizeof(locale_dir) - 21);
+	strcpy(locale_dir, LOCALEDIR);
 #endif
 
 	if (tifiles_instance)
@@ -89,12 +87,12 @@ TIEXPORT2 int TICALL tifiles_library_init()
 
 #if defined(ENABLE_NLS)
 	tifiles_info("setlocale: %s", setlocale(LC_ALL, ""));
-	tifiles_info("bindtextdomain: %s", bindtextdomain(PACKAGE, locale_dir));
-	bind_textdomain_codeset(PACKAGE, "UTF-8"/*"ISO-8859-15"*/);
-	tifiles_info("textdomain: %s", textdomain(NULL));
+  	tifiles_info("bindtextdomain: %s", bindtextdomain(PACKAGE, locale_dir));
+  	//bind_textdomain_codeset(PACKAGE, "UTF-8"/*"ISO-8859-15"*/);
+  	tifiles_info("textdomain: %s", textdomain(PACKAGE));
 #endif
 
-	return (++tifiles_instance);
+  	return (++tifiles_instance);
 }
 
 /**
@@ -106,7 +104,7 @@ TIEXPORT2 int TICALL tifiles_library_init()
  **/
 TIEXPORT2 int TICALL tifiles_library_exit()
 {
-	return (--tifiles_instance);
+  	return (--tifiles_instance);
 }
 
 /***********/
