@@ -36,8 +36,15 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <archive.h>
-#include <archive_entry.h>
+#include "minizip/zip.h"
+#include "minizip/unzip.h"
+
+/*
+#ifdef WIN32
+# define USEWIN32IOAPI
+# include "minizip/iowin32.h"
+#endif
+*/
 
 #include <ticonv.h>
 #include "tifiles.h"
@@ -45,11 +52,11 @@
 #include "error.h"
 #include "rwfile.h"
 
-// Whether to print detailed information about TigEntry, TigContent instances throughout their lifecycle.
-//#define TRACE_CONTENT_INSTANCES
-
 #define WRITEBUFFERSIZE (8192)
 
+extern uLong filetime(char *f, tm_zip *tmzip, uLong *dt);
+extern int do_list(unzFile uf);
+
 /**
  * tifiles_te_create:
  * @filename: internal filename in archive.
@@ -69,17 +76,13 @@ TIEXPORT2 TigEntry* TICALL tifiles_te_create(const char *filename, FileClass typ
 		entry = (TigEntry *)g_malloc0(sizeof(TigEntry));
 		if (entry != NULL)
 		{
-			entry->filename = g_path_get_basename(filename);
+			entry->filename = g_strdup(g_basename(filename));
 			entry->type = type;
 
-			if (type == TIFILE_FLASH)
-			{
+			if(type == TIFILE_FLASH)
 				entry->content.flash = tifiles_content_create_flash(model);
-			}
-			else if (type & TIFILE_REGULAR)
-			{
+			else if(type & TIFILE_REGULAR)
 				entry->content.regular = tifiles_content_create_regular(model);
-			}
 		}
 	}
 	else
@@ -87,10 +90,6 @@ TIEXPORT2 TigEntry* TICALL tifiles_te_create(const char *filename, FileClass typ
 		tifiles_critical("%s: invalid filename", __FUNCTION__);
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_te_create: %p", entry);
-	tifiles_te_display(entry);
-#endif
 
 	return entry;
 }
@@ -101,27 +100,18 @@ TIEXPORT2 TigEntry* TICALL tifiles_te_create(const char *filename, FileClass typ
  *
  * Destroy a #TigEntry structure as well as fields.
  *
- * Return value: always 0.
+ * Return value: none.
  **/
 TIEXPORT2 int TICALL tifiles_te_delete(TigEntry* entry)
 {
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_te_delete: %p", entry);
-	tifiles_te_display(entry);
-#endif
-
 	if (entry != NULL)
 	{
 		g_free(entry->filename);
 
-		if (entry->type == TIFILE_FLASH)
-		{
+		if(entry->type == TIFILE_FLASH)
 			tifiles_content_delete_flash(entry->content.flash);
-		}
-		else if (entry->type & TIFILE_REGULAR)
-		{
+		else if(entry->type & TIFILE_REGULAR)
 			tifiles_content_delete_regular(entry->content.regular);
-		}
 
 		g_free(entry);
 	}
@@ -133,51 +123,16 @@ TIEXPORT2 int TICALL tifiles_te_delete(TigEntry* entry)
 	return 0;
 }
 
-/**
- * tifiles_te_display:
- * @entry: a #TigEntry structure pointer.
- *
- * Display a #TigEntry structure's contents.
- *
- * Return value: an error code, 0 otherwise.
- **/
-TIEXPORT2 int TICALL tifiles_te_display(TigEntry* entry)
-{
-	if (entry == NULL)
-	{
-		tifiles_critical("%s(NULL)", __FUNCTION__);
-		return ERR_INVALID_FILE;
-	}
-
-	tifiles_info("Filename:          %s", entry->filename);
-	tifiles_info("File class:        %04X (%u)", entry->type, entry->type);
-
-	if (entry->type == TIFILE_FLASH)
-	{
-		tifiles_file_display_flash(entry->content.flash);
-	}
-	else if (entry->type & TIFILE_REGULAR)
-	{
-		tifiles_file_display_regular(entry->content.regular);
-	}
-	else
-	{
-		tifiles_info("Data:              %p", entry->content.data);
-	}
-
-	return 0;
-}
-
 /**
  * tifiles_te_create_array:
  * @nelts: size of NULL-terminated array (number of #TigEntry structures).
  *
  * Allocate a NULL-terminated array of #TigEntry structures. You have to allocate
- * each element of the array by yourself.
+ * each elements of the array by yourself.
  *
  * Return value: the array or NULL if error.
  **/
-TIEXPORT2 TigEntry**	TICALL tifiles_te_create_array(unsigned int nelts)
+TIEXPORT2 TigEntry**	TICALL tifiles_te_create_array(int nelts)
 {
 	return g_malloc0((nelts + 1) * sizeof(TigEntry *));
 }
@@ -188,18 +143,13 @@ TIEXPORT2 TigEntry**	TICALL tifiles_te_create_array(unsigned int nelts)
  * @nelts: size of NULL-terminated array (number of #TigEntry structures).
  *
  * Re-allocate a NULL-terminated array of #TigEntry structures. You have to allocate
- * each element of the array by yourself.
+ * each elements of the array by yourself.
  *
  * Return value: the array or NULL if error.
  **/
-TIEXPORT2 TigEntry**	TICALL tifiles_te_resize_array(TigEntry** array, unsigned int nelts)
+TIEXPORT2 TigEntry**	TICALL tifiles_te_resize_array(TigEntry** array, int nelts)
 {
-	TigEntry ** ptr = g_realloc(array, (nelts + 1) * sizeof(TigEntry *));
-	if (ptr != NULL)
-	{
-		ptr[nelts] = NULL;
-	}
-	return ptr;
+	return realloc(array, (nelts + 1) * sizeof(TigEntry *));
 }
 
 /**
@@ -214,16 +164,10 @@ TIEXPORT2 void			TICALL tifiles_te_delete_array(TigEntry** array)
 {
 	TigEntry** ptr;
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_te_delete_array: %p", array);
-#endif
-
 	if (array != NULL)
 	{
-		for (ptr = array; *ptr; ptr++)
-		{
+		for(ptr = array; ptr; ptr++)
 			tifiles_te_delete(*ptr);
-		}
 		g_free(array);
 	}
 	else
@@ -249,7 +193,7 @@ TIEXPORT2 int TICALL tifiles_te_sizeof_array(TigEntry** array)
 
 	if (array != NULL)
 	{
-		for (p = array; *p; p++, i++);
+		for(p = array; *p; p++, i++);
 	}
 	else
 	{
@@ -279,7 +223,7 @@ TIEXPORT2 int TICALL tifiles_content_add_te(TigContent *content, TigEntry *te)
 		return 0;
 	}
 
-	if (te->type == TIFILE_FLASH)
+	if(te->type == TIFILE_FLASH)
 	{
 		int n = content->n_apps;
 
@@ -291,7 +235,7 @@ TIEXPORT2 int TICALL tifiles_content_add_te(TigContent *content, TigEntry *te)
 
 		return n;
 	}
-	else if (te->type & TIFILE_REGULAR)
+	else if(te->type & TIFILE_REGULAR)
 	{
 		int n = content->n_vars;
 
@@ -318,7 +262,7 @@ TIEXPORT2 int TICALL tifiles_content_add_te(TigContent *content, TigEntry *te)
  **/
 TIEXPORT2 int TICALL tifiles_content_del_te(TigContent *content, TigEntry *te)
 {
-	unsigned int i, j, k;
+	int i, j, k;
 
 	if (content == NULL || te == NULL)
 	{
@@ -326,50 +270,36 @@ TIEXPORT2 int TICALL tifiles_content_del_te(TigContent *content, TigEntry *te)
 		return -1;
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_del_te: %p %p", content, te);
-	tifiles_file_display_tigcontent(content);
-	tifiles_te_display(te);
-#endif
-
 	// Search for entry
-	for (i = 0; i < content->n_vars && (te->type & TIFILE_REGULAR); i++)
+	for(i = 0; i < content->n_vars && (te->type & TIFILE_REGULAR); i++)
 	{
 		TigEntry *s = content->var_entries[i];
 
-		if (!strcmp(s->filename, te->filename))
-		{
+		if(!strcmp(s->filename, te->filename))
 			break;
-		}
 	}
 
-	for (j = 0; j < content->n_apps && (te->type & TIFILE_FLASH); j++)
+	for(j = 0; j < content->n_apps && (te->type & TIFILE_FLASH); j++)
 	{
 		TigEntry *s = content->app_entries[i];
 
-		if (!strcmp(s->filename, te->filename))
-		{
+		if(!strcmp(s->filename, te->filename))
 			break;
-		}
 	}
 
 	// Not found ? Exit !
-	if ((i == content->n_vars) && (j == content->n_apps))
-	{
+	if((i == content->n_vars) && (j == content->n_apps))
 		return -1;
-	}
 
 	// Release
-	if (i < content->n_vars)
+	if(i < content->n_vars)
 	{
 		// Delete
 		tifiles_te_delete(content->var_entries[i]);
 
 		// And shift
-		for (k = i; k < content->n_vars; k++)
-		{
+		for(k = i; k < content->n_vars; k++)
 			content->var_entries[k] = content->var_entries[k+1];
-		}
 		content->var_entries[k] = NULL;
 
 		// And resize
@@ -379,16 +309,14 @@ TIEXPORT2 int TICALL tifiles_content_del_te(TigContent *content, TigEntry *te)
 		return content->n_vars;
 	}
 
-	if (j < content->n_apps)
+	if(j < content->n_apps)
 	{
 		// Delete
 		tifiles_te_delete(content->app_entries[j]);
 
 		// And shift
-		for (k = j; k < content->n_apps; k++)
-		{
+		for(k = j; k < content->n_apps; k++)
 			content->app_entries[k] = content->app_entries[k+1];
-		}
 		content->app_entries[k] = NULL;
 
 		// And resize
@@ -429,72 +357,52 @@ TIEXPORT2 int TICALL tifiles_tigroup_add_file(const char *src_filename, const ch
 	}
 
 	// group file is created if non existent
-	if (!stricmp(tifiles_fext_get(dst_filename), "tig"))
+	if(!stricmp(tifiles_fext_get(dst_filename), "tig"))
 	{
-		if (!g_file_test(dst_filename, G_FILE_TEST_EXISTS))
+		if(!g_file_test(dst_filename, G_FILE_TEST_EXISTS))
 		{
 			content = tifiles_content_create_tigroup(CALC_NONE, 0);
 			tifiles_file_write_tigroup(dst_filename, content);
 			tifiles_content_delete_tigroup(content);
-			content = NULL;
 		}
 	}
 
 	// src can't be a TiGroup file but dst should be
-	if (!(tifiles_file_is_ti(src_filename) && !tifiles_file_is_tigroup(src_filename) &&
+	if(!(tifiles_file_is_ti(src_filename) && !tifiles_file_is_tigroup(src_filename) &&
 		tifiles_file_is_tigroup(dst_filename)))
-	{
 		return -1;
-	}
 
 	// load src file
 	model = tifiles_file_get_model(src_filename);
 	type = tifiles_file_get_class(src_filename);
-
+	
 	te = tifiles_te_create(src_filename, type, model);
-	if (te == NULL)
-	{
-		ret = ERR_BAD_FILE;
-		goto ttaf;
-	}
-	if (type == TIFILE_FLASH)
+	if(type == TIFILE_FLASH)
 	{ 
 		ret = tifiles_file_read_flash(src_filename, te->content.flash);
-		if (ret)
-		{
-			goto ttaf;
-		}
+		if(ret) goto ttaf;
 	}
-	else if (type & TIFILE_REGULAR)
+	else if(type & TIFILE_REGULAR)
 	{ 
 		ret = tifiles_file_read_regular(src_filename, te->content.regular);
-		if (ret)
-		{
-			goto ttaf;
-		}
+		if(ret) goto ttaf;
 	}
 
 	// load dst file
 	content = tifiles_content_create_tigroup(CALC_NONE, 0);
 	ret = tifiles_file_read_tigroup(dst_filename, content);
-	if (ret)
-	{
-		goto ttaf;
-	}
+	if(ret) goto ttaf;
 
 	tifiles_content_add_te(content, te);
 	ret = tifiles_file_write_tigroup(dst_filename, content);
-	if (ret)
-	{
-		goto ttaf;
-	}
+	if(ret) goto ttaf;
 
 	tifiles_content_delete_tigroup(content);
 
 	return 0;
 
 ttaf:	// release on exit
-	tifiles_te_delete(te);
+    tifiles_te_delete(te);
 	tifiles_content_delete_tigroup(content);
 	return ret;
 }
@@ -511,7 +419,7 @@ ttaf:	// release on exit
 TIEXPORT2 int TICALL tifiles_tigroup_del_file(TigEntry *entry, const char *filename)
 {
 	TigContent* content = NULL;
-	int ret = 0;
+	int err = 0;
 
 	if (entry == NULL || filename == NULL)
 	{
@@ -519,21 +427,17 @@ TIEXPORT2 int TICALL tifiles_tigroup_del_file(TigEntry *entry, const char *filen
 		return -1;
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_tigroup_del_file: %p", entry);
-	tifiles_te_display(entry);
-#endif
-
 	content = tifiles_content_create_tigroup(CALC_NONE, 0);
-	ret = tifiles_file_read_tigroup(filename, content);
-	if (!ret)
-	{
-		(void)tifiles_content_del_te(content, entry);
-		ret = tifiles_file_write_tigroup(filename, content);
-	}
+	err = tifiles_file_read_tigroup(filename, content);
+	if(err) goto tfdf;
 
+	tifiles_content_del_te(content, entry);
+	err = tifiles_file_write_tigroup(filename, content);
+	if(err) goto tfdf;
+
+tfdf:
 	tifiles_content_delete_tigroup(content);
-	return ret;
+	return 0;
 }
 
 // ---------------------------------------------------------------------------
@@ -555,10 +459,8 @@ TIEXPORT2 int TICALL tifiles_tigroup_contents(FileContent **src_contents1, Flash
 	int i, m=0, n=0;
 	CalcModel model = CALC_NONE;
 
-	if (src_contents1 == NULL && src_contents2 == NULL)
-	{
+	if(src_contents1 == NULL && src_contents2 == NULL)
 		return -1;
-	}
 
 	if (dst_content == NULL)
 	{
@@ -566,35 +468,23 @@ TIEXPORT2 int TICALL tifiles_tigroup_contents(FileContent **src_contents1, Flash
 		return -1;
 	}
 
-	if (src_contents1)
-	{
+	if(src_contents1)
 		for (m = 0; src_contents1[m] != NULL; m++);
-	}
-	if (src_contents2)
-	{
+	if(src_contents2)
 		for (n = 0; src_contents2[n] != NULL; n++);
-	}
 
-	if (src_contents2)
-	{
-		if (*src_contents2)
-		{
+	if(src_contents2)
+		if(*src_contents2)
 			model = src_contents2[0]->model;
-		}
-	}
-	if (src_contents1)
-	{
-		if (*src_contents1)
-		{
+	if(src_contents1)
+		if(*src_contents1)
 			model = src_contents1[0]->model;	// FileContent is more precise than FlashContent
-		}
-	}
 
 	content = tifiles_content_create_tigroup(model, m+n);
 
-	if (src_contents1)
+	if(src_contents1)
 	{
-		for (i = 0; i < m; i++)
+		for(i = 0; i < m; i++)
 		{
 			TigEntry *te = (TigEntry *)g_malloc0(sizeof(TigEntry));
 
@@ -605,31 +495,20 @@ TIEXPORT2 int TICALL tifiles_tigroup_contents(FileContent **src_contents1, Flash
 		}
 	}
 
-	if (src_contents2)
+	if(src_contents2)
 	{
-		for (i = 0; i < n; i++)
+		for(i = 0; i < n; i++)
 		{
-			TigEntry *te;
+			TigEntry *te = (TigEntry *)g_malloc0(sizeof(TigEntry));
 			VarEntry ve;
 			FlashContent *ptr;
 
 			for (ptr = src_contents2[i]; ptr; ptr = ptr->next)
-			{
-				if (ptr->data_type == tifiles_flash_type(model))
-				{
+				if(ptr->data_type == tifiles_flash_type(model))
 					break;
-				}
-			}
-			if (ptr == NULL)
-			{
-				tifiles_critical("%s: ptr is NULL, skipping", __FUNCTION__);
-				continue;
-			}
-
-			te = (TigEntry *)g_malloc0(sizeof(TigEntry));
-			ve.folder[0] = 0;
-			strncpy(ve.name, ptr->name, sizeof(ve.name) - 1);
-			ve.name[sizeof(ve.name) - 1] = 0;
+			
+			strcpy(ve.folder, "");
+			strcpy(ve.name, ptr->name);
 			ve.type = ptr->data_type;
 			te->filename = tifiles_build_filename(model, &ve);
 			te->type = TIFILE_FLASH;
@@ -640,11 +519,6 @@ TIEXPORT2 int TICALL tifiles_tigroup_contents(FileContent **src_contents1, Flash
 
 	*dst_content = content;
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_tigroup_contents: %p", content);
-	tifiles_file_display_tigcontent(content);
-#endif
-
 	return 0;
 }
 
@@ -665,7 +539,7 @@ TIEXPORT2 int TICALL tifiles_untigroup_content(TigContent *src_content, FileCont
 	TigContent *src = src_content;
 	FileContent **dst1 = NULL;
 	FlashContent **dst2 = NULL;
-	unsigned int i, j;
+	int i, j;
 
 	if (src_content == NULL || dst_contents1 == NULL || dst_contents2 == NULL)
 	{
@@ -673,33 +547,27 @@ TIEXPORT2 int TICALL tifiles_untigroup_content(TigContent *src_content, FileCont
 		return -1;
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_untigroup_content: %p", src_content);
-	tifiles_file_display_tigcontent(src_content);
-#endif
-
 	// allocate an array of FileContent/FlashContent structures (NULL terminated)
-	dst1 = (FileContent **)g_malloc0((src->n_vars+1) * sizeof(FileContent *));
-	if (dst1 == NULL)
 	{
-		return ERR_MALLOC;
+		dst1 = (FileContent **)g_malloc0((src->n_vars+1) * sizeof(FileContent *));
+		if (dst1 == NULL)
+			return ERR_MALLOC;
 	}
-	dst2 = (FlashContent **)g_malloc0((src->n_apps+1) * sizeof(FlashContent *));
-	if (dst2 == NULL)
 	{
-		g_free(dst1);
-		return ERR_MALLOC;
+		dst2 = (FlashContent **)g_malloc0((src->n_apps+1) * sizeof(FlashContent *));
+		if (dst2 == NULL)
+			return ERR_MALLOC;
 	}
 
 	// parse each entry and duplicate it into a single content
-	for (i = 0; i < src->n_vars; i++)
+	for(i = 0; i < src->n_vars; i++)
 	{
 		TigEntry *te = src->var_entries[i];
 
 		dst1[i] = tifiles_content_dup_regular(te->content.regular);
 	}
 
-	for (j = 0; j < src->n_apps; j++)
+	for(j = 0; j < src->n_apps; j++)
 	{
 		TigEntry *te = src->app_entries[j];
 
@@ -737,75 +605,54 @@ TIEXPORT2 int TICALL tifiles_tigroup_files(char **src_filenames, const char *dst
 	}
 
 	// counts number of files to group and allocate space for that
-	for (k = m = n = 0; src_filenames[k]; k++)
+	for(k = m = n = 0; src_filenames[k]; k++)
 	{
-		if (tifiles_file_is_regular(src_filenames[k]))
-		{
+		if(tifiles_file_is_regular(src_filenames[k]))
 			m++;
-		}
-		else if (tifiles_file_is_flash(src_filenames[k]))
-		{
+		else if(tifiles_file_is_flash(src_filenames[k]))
 			n++;
-		}
 	}
 	model = tifiles_file_get_model(src_filenames[0]);
 
 	// allocate space for that
 	src1 = (FileContent **)g_malloc0((m + 1) * sizeof(FileContent *));
 	if (src1 == NULL)
-	{
 		return ERR_MALLOC;
-	}
 
 	src2 = (FlashContent **)g_malloc0((n + 1) * sizeof(FlashContent *));
 	if (src2 == NULL)
-	{
-		g_free(src1);
 		return ERR_MALLOC;
-	}
 
-	for (i = j = k = 0; k < m+n; k++)
+	for(i = j = k = 0; k < m+n; k++)
 	{
-		if (tifiles_file_is_regular(src_filenames[k]))
+		if(tifiles_file_is_regular(src_filenames[k]))
 		{
 			src1[i] = tifiles_content_create_regular(model);
 			ret = tifiles_file_read_regular(src_filenames[k], src1[i]);
-			if (ret)
-			{
-				goto tgf;
-			}
+			if(ret) goto tgf;
 			i++;
 		}
-		else if (tifiles_file_is_flash(src_filenames[k]))
+		else if(tifiles_file_is_flash(src_filenames[k]))
 		{
 			src2[j] = tifiles_content_create_flash(model);
 			ret = tifiles_file_read_flash(src_filenames[k], src2[j]);
-			if (ret)
-			{
-				goto tgf;
-			}
+			if(ret) goto tgf;
 			j++;
 		}
 	}
 
 	ret = tifiles_tigroup_contents(src1, src2, &dst);
-	if (ret)
-	{
-		goto tgf;
-	}
+	if(ret) goto tgf;
 
 	ret = tifiles_file_write_tigroup(dst_filename, dst);
+	if(ret) goto tgf;
 
 tgf:
-	for (i = 0; i < m; i++)
-	{
+	for(i = 0; i < m; i++)
 		g_free(src1[i]);
-	}
 	g_free(src1);
-	for (i = 0; i < n; i++)
-	{
+	for(i = 0; i < n; i++)
 		g_free(src2[i]);
-	}
 	g_free(src2);
 	tifiles_content_delete_tigroup(dst);
 
@@ -832,7 +679,7 @@ TIEXPORT2 int TICALL tifiles_untigroup_file(const char *src_filename, char ***ds
 	FileContent **ptr1, **dst1 = NULL;
 	FlashContent **ptr2, **dst2 = NULL;
 	char *real_name;
-	unsigned int i, j;
+	int i, j;
 	int ret = 0;
 
 	if (src_filename == NULL)
@@ -844,76 +691,50 @@ TIEXPORT2 int TICALL tifiles_untigroup_file(const char *src_filename, char ***ds
 	// read TiGroup file
 	src = tifiles_content_create_tigroup(CALC_NONE, 0);
 	ret = tifiles_file_read_tigroup(src_filename, src);
-	if (ret)
-	{
-		goto tuf;
-	}
+	if(ret) goto tuf;
 
 	// ungroup structure
 	ret = tifiles_untigroup_content(src, &dst1, &dst2);
-	if (ret)
-	{
-		goto tuf;
-	}
+	if(ret) goto tuf;
 
 	// count number of structures and allocates array of strings
-	if (dst_filenames != NULL)
-	{
+	if(dst_filenames != NULL)
 		*dst_filenames = (char **)g_malloc((src->n_vars + src->n_apps + 1) * sizeof(char *));
-	}
 
 	// store each structure content to file
 	for (ptr1 = dst1, i = 0; *ptr1 != NULL || i < src->n_vars; ptr1++, i++)
 	{
 		ret = tifiles_file_write_regular(NULL, *ptr1, &real_name);
-		if (ret)
-		{
-			goto tuf;
-		}
+		if(ret) goto tuf;
 
-		if (dst_filenames != NULL)
-		{
+		if(dst_filenames != NULL)
 			*dst_filenames[i] = real_name;
-		}
 		else
-		{
 			g_free(real_name);
-		}
 	}
 
 	for (ptr2 = dst2, j = 0; *ptr2 != NULL || j < src->n_apps; ptr2++, j++)
 	{
 		ret = tifiles_file_write_flash2(NULL, *ptr2, &real_name);
-		if (ret)
-		{
-			goto tuf;
-		}
+		if(ret) goto tuf;
 
-		if (dst_filenames != NULL)
-		{
+		if(dst_filenames != NULL)
 			*dst_filenames[i+j] = real_name;
-		}
 		else
-		{
 			g_free(real_name);
-		}
 	}
 
 	// release allocated memory
 tuf:
-	if (dst1)
+	if(dst1)
 	{
-		for (ptr1 = dst1; *ptr1; ptr1++)
-		{
+		for(ptr1 = dst1; *ptr1; ptr1++)
 			tifiles_content_delete_regular(*ptr1);
-		}
 	}
-	if (dst2)
+	if(dst2)
 	{
-		for (ptr2 = dst2; *ptr2; ptr2++)
-		{
+		for(ptr2 = dst2; *ptr2; ptr2++)
 			tifiles_content_delete_flash(*ptr2);
-		}
 	}
 	tifiles_content_delete_tigroup(src);
 
@@ -932,9 +753,9 @@ tuf:
  *
  * Return value: the allocated block.
  **/
-TIEXPORT2 TigContent* TICALL tifiles_content_create_tigroup(CalcModel model, unsigned int n)
+TIEXPORT2 TigContent* TICALL tifiles_content_create_tigroup(CalcModel model, int n)
 {
-	TigContent* content = g_malloc0(sizeof(*content));
+	TigContent* content = g_malloc0(sizeof(FileContent));
 	if (content != NULL)
 	{
 		content->model = content->model_dst = model;
@@ -944,11 +765,6 @@ TIEXPORT2 TigContent* TICALL tifiles_content_create_tigroup(CalcModel model, uns
 		content->app_entries = (TigEntry **)g_malloc0(sizeof(TigEntry *));
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_create_tigroup: %p", content);
-	tifiles_file_display_tigcontent(content);
-#endif
-
 	return content;
 }
 
@@ -961,37 +777,21 @@ TIEXPORT2 TigContent* TICALL tifiles_content_create_tigroup(CalcModel model, uns
  **/
 TIEXPORT2 int TICALL tifiles_content_delete_tigroup(TigContent *content)
 {
-	unsigned int i;
-
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_content_delete_tigroup: %p", content);
-	tifiles_file_display_tigcontent(content);
-#endif
+	int i;
 
 	if (content != NULL)
 	{
-		if (content->var_entries != NULL)
+		for(i = 0; i < content->n_vars; i++)
 		{
-			for (i = 0; i < content->n_vars; i++)
-			{
-				TigEntry* entry = content->var_entries[i];
-				tifiles_te_delete(entry);
-			}
-			g_free(content->var_entries);
+			TigEntry* entry = content->var_entries[i];
+			tifiles_te_delete(entry);
 		}
 
-		if (content->app_entries != NULL)
+		for(i = 0; i < content->n_apps; i++)
 		{
-			for (i = 0; i < content->n_apps; i++)
-			{
-				TigEntry* entry = content->app_entries[i];
-				tifiles_te_delete(entry);
-			}
-			g_free(content->app_entries);
+			TigEntry* entry = content->app_entries[i];
+			tifiles_te_delete(entry);
 		}
-
-		g_free(content->comment);
-
 		g_free(content);
 	}
 	else
@@ -1002,39 +802,12 @@ TIEXPORT2 int TICALL tifiles_content_delete_tigroup(TigContent *content)
 	return 0;
 }
 
-/* Open a temporary file */
-static int open_temp_file(const char *orig_name, char **temp_name)
-{
-	const char *suffix;
-	char *template;
-	int fd;
-
-	*temp_name = NULL;
-	suffix = strrchr(orig_name, '.');
-	if (suffix && (strchr(suffix, '/') || strchr(suffix, '\\')))
-	{
-		suffix = NULL;
-	}
-	template = g_strconcat("tigXXXXXX", suffix, NULL);
-
-	fd = g_file_open_tmp(template, temp_name, NULL);
-
-	g_free(template);
-	if (fd == -1) {
-		g_free(*temp_name);
-		*temp_name = NULL;
-	}
-
-	return fd;
-}
-
 /**
  * tifiles_file_read_tigroup:
  * @filename: the name of file to load.
  * @content: where to store content (may be re-allocated).
  *
- * This function loads a TiGroup from \a filename and places its content into \a content.
- * If an error occurs, the structure content is *NOT* released for you.
+ * This function load & TiGroup and place its content into content.
  *
  * The temporary folder is used by this function to store temporary files.
  * 
@@ -1042,11 +815,15 @@ static int open_temp_file(const char *orig_name, char **temp_name)
  **/
 TIEXPORT2 int TICALL tifiles_file_read_tigroup(const char *filename, TigContent *content)
 {
-	FILE *tigf;
-	struct archive *arc;
-	struct archive_entry *entry;
-	const char *filename_inzip;
-	int ret = 0;
+	unzFile uf = NULL;
+	unz_global_info gi;
+	unz_file_info file_info;
+	int cnt, err = UNZ_OK;
+	char filename_inzip[256];
+	unsigned i;
+	void* buf = NULL;
+	const char *password = NULL;
+	int vi = 0, ai = 0;
 
 	if (filename == NULL || content == NULL)
 	{
@@ -1055,221 +832,252 @@ TIEXPORT2 int TICALL tifiles_file_read_tigroup(const char *filename, TigContent
 	}
 
 	// Open ZIP archive
-	tigf = g_fopen(filename, "rb");
-	if (tigf == NULL)
+	uf = unzOpen(filename);
+	if (uf == NULL)
 	{
-		return ERR_FILE_OPEN;
-	}
-
-	if (!(arc = archive_read_new())
-	    || archive_read_support_format_zip(arc) != ARCHIVE_OK
-	    || archive_read_open_FILE(arc, tigf) != ARCHIVE_OK)
-	{
-		if (arc)
-		{
-			archive_read_free(arc);
-		}
-		fclose(tigf);
+		printf("Can't open this file: %s\n", filename);
 		return ERR_FILE_ZIP;
 	}
 
+	// Allocate
+	buf = (void*)malloc(WRITEBUFFERSIZE);
+	if (buf==NULL)
+	{
+		printf("Error allocating memory\n");
+		goto tfrt_exit;
+	}
+
+	// Size of comment and number of files in archive
+	err = unzGetGlobalInfo (uf,&gi);
+	if (err!=UNZ_OK)
+	{
+		printf("error %d with zipfile in unzGetGlobalInfo \n",err);
+		goto tfrt_exit;
+	}        
+	//printf("# entries: %lu\n", gi.number_entry);
+
 	g_free(content->var_entries);
-	content->var_entries = (TigEntry **)g_malloc0(1 * sizeof(TigEntry *));
+	content->var_entries = (TigEntry **)g_malloc0((gi.number_entry + 1) * sizeof(TigEntry *));
 	content->n_vars = 0;
 
 	g_free(content->app_entries);
-	content->app_entries = (TigEntry **)g_malloc0(1 * sizeof(TigEntry *));
+	content->app_entries = (TigEntry **)g_malloc0((gi.number_entry + 1) * sizeof(TigEntry *));
 	content->n_apps = 0;
 
 	// Get comment
 	g_free(content->comment);
-	// FIXME: any way to get this from libarchive?
-	content->comment = g_strdup("");
+	content->comment = (char *)g_malloc((gi.size_comment+1) * sizeof(char));
+	err = unzGetGlobalComment(uf, content->comment, gi.size_comment);
 
 	// Parse archive for files
-	while (archive_read_next_header(arc, &entry) == ARCHIVE_OK)
+	for (i = 0; i < gi.number_entry; i++)
 	{
+		FILE *f;
 		gchar *fname;
-		int fd;
+		gchar *utf8;
+		gchar *gfe;
 
-		filename_inzip = archive_entry_pathname(entry);
-		if (!filename_inzip)
+		// get infos
+		err = unzGetCurrentFileInfo(uf,&file_info,filename_inzip,sizeof(filename_inzip),NULL,0,NULL,0);
+		if (err!=UNZ_OK)
 		{
-			tifiles_warning("archive contains a file with no name");
-			archive_read_data_skip(arc);
-			continue;
+			printf("error %d with zipfile in unzGetCurrentFileInfo\n",err);
+			goto tfrt_exit;
 		}
+		//printf("Extracting %s with %lu bytes\n", filename_inzip, file_info.uncompressed_size);
 
-		// create a temporary file
-		fd = open_temp_file(filename_inzip, &fname);
-		if (fd == -1)
+		err = unzOpenCurrentFilePassword(uf,password);
+		if (err!=UNZ_OK)
 		{
-			ret = ERR_FILE_IO;
+			printf("error %d with zipfile in unzOpenCurrentFilePassword\n",err);
 			goto tfrt_exit;
 		}
 
-		// extract data into temporary file
-		if (archive_read_data_into_fd(arc, fd) != ARCHIVE_OK)
+		// extract/uncompress into temporary file
+		utf8 = g_locale_to_utf8(filename_inzip, -1, NULL, NULL, NULL);
+		gfe = g_filename_from_utf8(utf8, -1, NULL, NULL, NULL);
+		fname = g_strconcat(g_get_tmp_dir(), G_DIR_SEPARATOR_S, gfe, NULL);
+		g_free(utf8);
+		g_free(gfe);
+
+		f = g_fopen(fname, "wb");
+		if(f == NULL)
 		{
-			close(fd);
-			g_unlink(fname);
-			g_free(fname);
-			ret = ERR_FILE_IO;
+			err = ERR_FILE_OPEN;
 			goto tfrt_exit;
 		}
-		close(fd);
+
+		do
+		{
+			err = unzReadCurrentFile(uf,buf,WRITEBUFFERSIZE);
+			if (err<0)
+			{
+				printf("error %d with zipfile in unzReadCurrentFile\n",err);
+				fclose(f);
+				goto tfrt_exit;
+			}
+			if (err>0)
+			{
+				cnt = fwrite(buf, 1, err, f);
+				if(cnt == -1)
+				{
+					printf("error in writing extracted file\n");
+					err=UNZ_ERRNO;
+					fclose(f);
+					goto tfrt_exit;
+				}
+			}
+		}
+		while (err>0);
+		fclose(f);
 
 		// add to TigContent
 		{
 			int model = tifiles_file_get_model(fname);
 
-			if (content->model == CALC_NONE)
-			{
+			if(content->model == CALC_NONE)
 				content->model = model;
-			}
 
-			if (tifiles_file_is_regular(fname))
+			if(tifiles_file_is_regular(fname))
 			{
-				TigEntry *tigentry = tifiles_te_create(filename_inzip, tifiles_file_get_class(fname), content->model);
+				TigEntry *entry = tifiles_te_create(filename_inzip, tifiles_file_get_class(fname), content->model);
+				int ret;
 
-				if (tigentry != NULL)
-				{
-					ret = tifiles_file_read_regular(fname, tigentry->content.regular);
-					if (ret)
-					{
-						g_free(tigentry);
-						g_unlink(fname);
-						g_free(fname);
-						break;
-					}
+				ret = tifiles_file_read_regular(fname, entry->content.regular);
+				if(ret) { g_free(entry); unlink(fname); g_free(fname); err = ret; goto tfrt_exit; }
 
-					tifiles_content_add_te(content, tigentry);
-				}
+				content->var_entries[vi++] = entry;
+				content->n_vars++;
 			}
-			else if (tifiles_file_is_flash(fname))
+			else if(tifiles_file_is_flash(fname))
 			{
-				TigEntry *tigentry = tifiles_te_create(filename_inzip, tifiles_file_get_class(fname), content->model);
+				TigEntry *entry = tifiles_te_create(filename_inzip, tifiles_file_get_class(fname), content->model);
+				int ret;
 
-				if (tigentry != NULL)
-				{
-					ret = tifiles_file_read_flash(fname, tigentry->content.flash);
-					if (ret)
-					{
-						g_free(tigentry);
-						g_unlink(fname);
-						g_free(fname);
-						break;
-					}
+				ret = tifiles_file_read_flash(fname, entry->content.flash);
+				if(ret) { g_free(entry); unlink(fname); g_free(fname); err = ret; goto tfrt_exit; }
 
-					tifiles_content_add_te(content, tigentry);
-				}
+				content->app_entries[ai++] = entry;
+				content->n_apps++;
 			}
 			else
 			{
 				// skip
 			}
 		}
-		g_unlink(fname);
+		unlink(fname);
 		g_free(fname);
-	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_file_read_tigroup: %p", content);
-	tifiles_file_display_tigcontent(content);
-#endif
+		// next file
+		if ((i+1) < gi.number_entry)
+		{
+			err = unzGoToNextFile(uf);
+			if (err!=UNZ_OK)
+			{
+				printf("error %d with zipfile in unzGoToNextFile\n",err);
+				goto tfrt_exit;
+			}
+		}
+	}
 
 	// Close
 tfrt_exit:
-	archive_read_free(arc);
-	fclose(tigf);
-	return ret;
+	g_free(buf);
+	unzCloseCurrentFile(uf);
+	return err ? ERR_FILE_ZIP : 0;
 }
 
-static int zip_write(struct archive *arc, CalcModel model, const char *origfname, const char *tempfname)
+static int zip_write(zipFile *zf, const char *fname, int comp_level)
 {
-	char *filenameinzip;
-	struct archive_entry *entry;
-	struct stat st;
-	int err = 0;
+	int err = ZIP_OK;
 	FILE *f = NULL;
+	zip_fileinfo zi;
+	char filenameinzip[256];
+	unsigned long crcFile=0;
 	int size_read;
 	void* buf=NULL;
 
-	if (arc == NULL)
+	if (zf == NULL)
 	{
-		tifiles_critical("zip_write: arc is NULL !");
+		tifiles_critical("zip_write: zf is NULL !");
 		return ERR_FILE_ZIP;
 	}
 
-	// Set metadata
-	entry = archive_entry_new();
-	if (entry == NULL)
-	{
-		tifiles_critical("zip_write: cannot allocate archive entry");
-		return ERR_FILE_ZIP;
-	}
-
-	if (g_stat(tempfname, &st))
-	{
-		tifiles_critical("zip_write: cannot stat temporary file");
-		archive_entry_free(entry);
-		return ERR_FILE_IO;
-	}
-	archive_entry_copy_stat(entry, &st);
-
-	// ZIP archives don't like greek chars
-	filenameinzip = ticonv_gfe_to_zfe(model, origfname);
-	archive_entry_set_pathname(entry, filenameinzip);
-	g_free(filenameinzip);
-
 	// missing tmp file !
-	f = g_fopen(tempfname, "rb");
-	if (f == NULL)
+	f = g_fopen(fname, "rb");
+	if(f == NULL)
 	{
-		tifiles_critical("zip_write: cannot read temporary file");
-		archive_entry_free(entry);
-		err = ERR_FILE_IO;
-		goto end2;
+		printf("error in opening tmp file %s\n", fname);
+		err = ERR_FILE_OPEN;
+		goto zw_exit;
 	}
-
-	if (archive_write_header(arc, entry) != ARCHIVE_OK)
-	{
-		archive_entry_free(entry);
-		err = ERR_FILE_IO;
-		goto end;
-	}
-	archive_entry_free(entry);
+	strcpy(filenameinzip, fname);
 
 	// Allocate buffer
 	buf = (void*)g_malloc(WRITEBUFFERSIZE);
+	if (buf==NULL)
+	{
+		printf("Error allocating memory\n");
+		goto zw_exit;
+	}
+
+	// update time stamp (to do ?)
+	zi.tmz_date.tm_sec = zi.tmz_date.tm_min = zi.tmz_date.tm_hour =
+	zi.tmz_date.tm_mday = zi.tmz_date.tm_mon = zi.tmz_date.tm_year = 0;
+	zi.dosDate = 0;
+	zi.internal_fa = 0;
+	zi.external_fa = 0;
+	filetime(filenameinzip,&zi.tmz_date,&zi.dosDate);
+
+	err = zipOpenNewFileInZip3(*zf,filenameinzip,&zi,
+                                   NULL,0,NULL,0,NULL /* comment*/,
+                                   comp_level ? Z_DEFLATED : 0 /* comp method */,
+                                   1 /*comp level */,0,
+                                   -MAX_WBITS, DEF_MEM_LEVEL, Z_DEFAULT_STRATEGY,
+                                   NULL /* no pwd*/,crcFile);
+	if (err != ZIP_OK)
+	{
+		printf("error in opening %s in zipfile\n",filenameinzip);
+		return ERR_FILE_ZIP;
+	}
 
 	do
 	{
 		// feed with our data
+		err = ZIP_OK;
 		size_read = fread(buf, 1, WRITEBUFFERSIZE, f);
 
 		if (size_read < WRITEBUFFERSIZE)
 		{
 			if (!feof(f))
 			{
-				tifiles_critical("error in reading %s", tempfname);
-				err = ERR_FILE_IO;
+				printf("error in reading %s\n",filenameinzip);
+				err = ZIP_ERRNO;
+				goto zw_exit;
 			}
 		}
 		if (size_read > 0)
 		{
-			if (archive_write_data(arc, buf, size_read) != size_read)
+			err = zipWriteInFileInZip (*zf,buf,size_read);
+			if (err<0)
 			{
-				tifiles_critical("error in writing %s in the zipfile\n", origfname);
-				err = ERR_FILE_IO;
+				printf("error in writing %s in the zipfile\n", filenameinzip);
+				goto zw_exit;
 			}
 		}
-	} while (!err && (size_read>0));
+	} while ((err == ZIP_OK) && (size_read>0));
 
+	// close file
+	err = zipCloseFileInZip(*zf);
+	if (err!=ZIP_OK)
+	{
+		printf("error in closing %s in the zipfile\n", filenameinzip);
+		goto zw_exit;
+	}
+
+zw_exit:
 	g_free(buf);
-end:
 	fclose(f);
-end2:
 	return err;
 }
 
@@ -1287,9 +1095,9 @@ end2:
  **/
 TIEXPORT2 int TICALL tifiles_file_write_tigroup(const char *filename, TigContent *content)
 {
-	FILE *tigf;
-	struct archive *arc;
-	int err = 0;
+	zipFile zf;
+	int err = ZIP_OK;
+	gchar *old_dir = g_get_current_dir();
 	TigEntry **ptr;
 
 	if (filename == NULL || content == NULL)
@@ -1298,107 +1106,68 @@ TIEXPORT2 int TICALL tifiles_file_write_tigroup(const char *filename, TigContent
 		return -1;
 	}
 
-#ifdef TRACE_CONTENT_INSTANCES
-	tifiles_info("tifiles_file_write_tigroup: %p", content);
-	tifiles_file_display_tigcontent(content);
+	// Open ZIP archive (and set comment)
+#ifdef USEWIN32IOAPI
+	zlib_filefunc_def ffunc;
+	fill_win32_filefunc(&ffunc);
+
+	zf = zipOpen2(filename, APPEND_STATUS_CREATE, &(content->comment), &ffunc);
+#else
+	zf = zipOpen(filename, APPEND_STATUS_CREATE);
 #endif
-
-	// Open ZIP archive
-	tigf = g_fopen(filename, "wb");
-	if (tigf == NULL)
+	if (zf == NULL)
 	{
-		return ERR_FILE_OPEN;
-	}
-
-	if (!(arc = archive_write_new()) || archive_write_set_format_zip(arc) != ARCHIVE_OK)
-	{
-		if (arc)
-		{
-			archive_write_close(arc);
-			archive_write_free(arc);
-		}
-		fclose(tigf);
-		return ERR_FILE_OPEN;
-	}
-
-	// tell libarchive not to pad output to 10240-byte blocks (why
-	// this is not the default for zip format, I have no idea)
-	archive_write_set_bytes_per_block(arc, 0);
-
-	if (content->comp_level > 0)
-	{
-		archive_write_set_options(arc, "compression=deflate");
-	}
-	else
-	{
-		archive_write_set_options(arc, "compression=store");
-	}
-
-	if (archive_write_open_FILE(arc, tigf) != ARCHIVE_OK)
-	{
-		err = ERR_FILE_OPEN;
+		printf("Can't open this file: %s\n", filename);
+		return ERR_FILE_ZIP;
 	}
+	g_chdir(g_get_tmp_dir());
 
 	// Parse entries and store
-	for (ptr = content->var_entries; *ptr && !err; ptr++)
+	for(ptr = content->var_entries; *ptr; ptr++)
 	{
 		TigEntry* entry = *ptr;
 		char *fname = NULL;
-		int fd;
+
+		// ZIP archives don't like greek chars
+		fname = ticonv_gfe_to_zfe(content->model, entry->filename);
 
 		// write TI file into tmp folder
-		fd = open_temp_file(entry->filename, &fname);
-		if (fd == -1)
-		{
-			g_free(fname);
-			err = ERR_FILE_OPEN;
-			break;
-		}
-		close(fd);
+		TRYC(tifiles_file_write_regular(fname, entry->content.regular, NULL));
 
-		err = tifiles_file_write_regular(fname, entry->content.regular, NULL);
-		if (!err)
-		{
-			err = zip_write(arc, content->model, entry->filename, fname);
-		}
-
-		g_unlink(fname);
+		err = zip_write(&zf, fname, content->comp_level);
 		g_free(fname);
+
+		if(err)
+			break;
 	}
 
-	for (ptr = content->app_entries; *ptr && !err; ptr++)
+	for(ptr = content->app_entries; *ptr; ptr++)
 	{
 		TigEntry* entry = *ptr;
 		char *fname = NULL;
-		int fd;
+
+		// ZIP archives don't like greek chars
+		fname = ticonv_gfe_to_zfe(content->model, entry->filename);
 
 		// write TI file into tmp folder
-		fd = open_temp_file(entry->filename, &fname);
-		if (fd == -1)
-		{
-			g_free(fname);
-			err = ERR_FILE_OPEN;
-			break;
-		}
-		close(fd);
+		TRYC(tifiles_file_write_flash(fname, entry->content.flash));
 
-		err = tifiles_file_write_flash(fname, entry->content.flash);
-		if (!err)
-		{
-			err = zip_write(arc, content->model, entry->filename, fname);
-		}
-
-		g_unlink(fname);
+		err = zip_write(&zf, fname, content->comp_level);
 		g_free(fname);
+
+		if(err)
+			break;
 	}
 
 	// close archive
-	if (archive_write_close(arc) != ARCHIVE_OK)
+	err = zipClose(zf,NULL);
+	if (err != ZIP_OK)
 	{
-		err = ERR_FILE_IO;
+		printf("error in closing %s\n",filename);
+		unlink(filename);
 	}
-	archive_write_free(arc);
-	fclose(tigf);
+
+	g_chdir(old_dir);
 	return err;
 }
 
@@ -1412,9 +1181,7 @@ TIEXPORT2 int TICALL tifiles_file_write_tigroup(const char *filename, TigContent
  **/
 TIEXPORT2 int TICALL tifiles_file_display_tigroup(const char *filename)
 {
-	FILE *tigf;
-	struct archive *arc;
-	struct archive_entry *entry;
+	unzFile uf = NULL;
 
 	if (filename == NULL)
 	{
@@ -1422,88 +1189,15 @@ TIEXPORT2 int TICALL tifiles_file_display_tigroup(const char *filename)
 		return -1;
 	}
 
-	tigf = g_fopen(filename, "rb");
-	if (tigf == NULL)
+	uf = unzOpen(filename);
+	if (uf==NULL)
 	{
-		return ERR_FILE_OPEN;
+		tifiles_warning("Can't open this file: %s", filename);
+		return -1;
 	}
 
-	if (!(arc = archive_read_new())
-	    || archive_read_support_format_zip(arc) != ARCHIVE_OK
-	    || archive_read_open_FILE(arc, tigf) != ARCHIVE_OK)
-	{
-		if (arc)
-		{
-			archive_read_free(arc);
-		}
-		fclose(tigf);
-		return ERR_FILE_ZIP;
-	}
-
-	tifiles_info("TIGroup file contents:");
-	tifiles_info(" Size    Name");
-	tifiles_info(" ------  ------");
-
-	while (archive_read_next_header(arc, &entry) == ARCHIVE_OK)
-	{
-		const char *name = archive_entry_pathname(entry);
-		char *dispname = g_filename_display_name(name);
-		unsigned long size = (unsigned long) archive_entry_size(entry);
-		tifiles_info(" %-7lu %s", size, dispname);
-		archive_read_data_skip(arc);
-		g_free(dispname);
-	}
-
-	archive_read_free(arc);
-	fclose(tigf);
-	return 0;
-}
-
-/**
- * tifiles_file_display_tigcontent:
- * @content: the tigroup content to show, TigContent pointer.
- *
- * Display tigroup information contained in a TigContent structure.
- *
- * Return value: an error code, 0 otherwise.
- **/
-TIEXPORT2 int TICALL tifiles_file_display_tigcontent(TigContent *content)
-{
-	unsigned int i;
-
-	if (content == NULL)
-	{
-		tifiles_critical("%s(NULL)", __FUNCTION__);
-		return ERR_INVALID_FILE;
-	}
-
-	tifiles_info("Model:             %02X (%u)", content->model, content->model);
-	tifiles_info("Signature:         %s", tifiles_calctype2signature(content->model));
-	tifiles_info("model_dst:         %02X (%u)", content->model_dst, content->model_dst);
-	tifiles_info("Comment:           %s", content->comment);
-	tifiles_info("Compression level: %d", content->comp_level);
-
-	tifiles_info("Number of vars:    %u", content->n_vars);
-	tifiles_info("Var entries:       %p", content->var_entries);
-
-	if (content->var_entries != NULL)
-	{
-		for (i = 0; i < content->n_vars; i++)
-		{
-			tifiles_te_display(content->var_entries[i]);
-		}
-	}
-
-	tifiles_info("Number of apps:    %u", content->n_apps);
-	tifiles_info("Apps entries:      %p", content->app_entries);
-
-	if (content->app_entries != NULL)
-	{
-		for (i = 0; i < content->n_apps; i++)
-		{
-			tifiles_te_display(content->app_entries[i]);
-		}
-	}
+	do_list(uf);
+	unzCloseCurrentFile(uf);
 
 	return 0;
 }
