@@ -20,18 +20,15 @@
  */
 
 #include <stdio.h>
-#include <string.h>
-#include "tifiles.h"
 #include "gettext.h"
+#include "tifiles.h"
 #include "logging.h"
-#include "internal.h"
-#include "typesxx.h"
 #include "error.h"
+#include "typesxx.h"
 #include "rwfile.h"
 
-
 /********************************/
-/* Calculator independent types */
+/* Calculator independant types */
 /********************************/
 
 /**
@@ -49,31 +46,20 @@ TIEXPORT2 const char *TICALL tifiles_vartype2string(CalcModel model, uint8_t dat
   {
 #ifndef DISABLE_TI8X
   case CALC_TI73:
-    return tixx_byte2type(TI73_CONST, TI73_MAXTYPES, data);
+    return ti73_byte2type(data);
   case CALC_TI82:
-    return tixx_byte2type(TI82_CONST, TI82_MAXTYPES, data);
+    return ti82_byte2type(data);
   case CALC_TI83:
-    return tixx_byte2type(TI83_CONST, TI83_MAXTYPES, data);
+    return ti83_byte2type(data);
   case CALC_TI83P:
     return ti83p_byte2type(data);
   case CALC_TI84P:
   case CALC_TI84P_USB:
     return ti84p_byte2type(data);
-  case CALC_TI82A_USB:
-    return ti82a_byte2type(data);
-  case CALC_TI84PT_USB:
-    return ti84pt_byte2type(data);
-  case CALC_TI84PC:
-  case CALC_TI84PC_USB:
-    return ti84pc_byte2type(data);
-  case CALC_TI83PCE_USB:
-    return ti83pce_byte2type(data);
-  case CALC_TI84PCE_USB:
-    return ti84pce_byte2type(data);
   case CALC_TI85:
-    return tixx_byte2type(TI85_CONST, TI85_MAXTYPES, data);
+    return ti85_byte2type(data);
   case CALC_TI86:
-    return tixx_byte2type(TI86_CONST, TI86_MAXTYPES, data);
+    return ti86_byte2type(data);
 #endif
 #ifndef DISABLE_TI9X
   case CALC_TI89:
@@ -88,7 +74,7 @@ TIEXPORT2 const char *TICALL tifiles_vartype2string(CalcModel model, uint8_t dat
   case CALC_V200:
     return v200_byte2type(data);
   case CALC_NSPIRE:
-    return tixx_byte2type(NSP_CONST, NSP_MAXTYPES, data);
+    return nsp_byte2type(data);
 #endif
   default:
     tifiles_critical("%s: invalid model argument.", __FUNCTION__);
@@ -117,38 +103,25 @@ TIEXPORT2 uint8_t TICALL tifiles_string2vartype(CalcModel model, const char *s)
   {
 #ifndef DISABLE_TI8X
   case CALC_TI73:
-    return tixx_type2byte(TI73_CONST, TI73_MAXTYPES, s);
+    return ti73_type2byte(s);
   case CALC_TI82:
-    return tixx_type2byte(TI82_CONST, TI82_MAXTYPES, s);
+    return ti82_type2byte(s);
   case CALC_TI83:
-    return tixx_type2byte(TI83_CONST, TI83_MAXTYPES, s);
+    return ti83_type2byte(s);
   case CALC_TI83P:
-    return ti83p_type2byte(s);
   case CALC_TI84P:
   case CALC_TI84P_USB:
-    return ti84p_type2byte(s);
-  case CALC_TI82A_USB:
-    return ti82a_type2byte(s);
-  case CALC_TI84PT_USB:
-    return ti84pt_type2byte(s);
-  case CALC_TI84PC:
-  case CALC_TI84PC_USB:
-    return ti84pc_type2byte(s);
-  case CALC_TI83PCE_USB:
-    return ti83pce_type2byte(s);
-  case CALC_TI84PCE_USB:
-    return ti84pce_type2byte(s);
+    return ti83p_type2byte(s);
   case CALC_TI85:
-    return tixx_type2byte(TI85_CONST, TI85_MAXTYPES, s);
+    return ti85_type2byte(s);
   case CALC_TI86:
-    return tixx_type2byte(TI86_CONST, TI86_MAXTYPES, s);
+    return ti86_type2byte(s);
 #endif
 #ifndef DISABLE_TI9X
   case CALC_TI89:
-    return ti89_type2byte(s);
   case CALC_TI89T:
   case CALC_TI89T_USB:
-    return ti89t_type2byte(s);
+    return ti89_type2byte(s);
   case CALC_TI92:
     return ti92_type2byte(s);
   case CALC_TI92P:
@@ -156,7 +129,7 @@ TIEXPORT2 uint8_t TICALL tifiles_string2vartype(CalcModel model, const char *s)
   case CALC_V200:
     return v200_type2byte(s);
   case CALC_NSPIRE:
-    return tixx_type2byte(NSP_CONST, NSP_MAXTYPES, s);
+    return nsp_type2byte(s);
 #endif
   default:
     tifiles_critical("%s: invalid model argument.", __FUNCTION__);
@@ -179,38 +152,25 @@ TIEXPORT2 const char *TICALL tifiles_vartype2fext(CalcModel model, uint8_t data)
   {
 #ifndef DISABLE_TI8X
   case CALC_TI73:
-    return tixx_byte2fext(TI73_CONST, TI73_MAXTYPES, data, "73?");
+    return ti73_byte2fext(data);
   case CALC_TI82:
-    return tixx_byte2fext(TI82_CONST, TI82_MAXTYPES, data, "82?");
+    return ti82_byte2fext(data);
   case CALC_TI83:
-    return tixx_byte2fext(TI83_CONST, TI83_MAXTYPES, data, "83?");
+    return ti83_byte2fext(data);
   case CALC_TI83P:
-    return ti83p_byte2fext(data);
   case CALC_TI84P:
   case CALC_TI84P_USB:
-    return ti84p_byte2fext(data);
-  case CALC_TI82A_USB:
-    return ti82a_byte2fext(data);
-  case CALC_TI84PT_USB:
-    return ti84pt_byte2fext(data);
-  case CALC_TI84PC:
-  case CALC_TI84PC_USB:
-    return ti84pc_byte2fext(data);
-  case CALC_TI83PCE_USB:
-    return ti83pce_byte2fext(data);
-  case CALC_TI84PCE_USB:
-    return ti84pce_byte2fext(data);
+    return ti83p_byte2fext(data);
   case CALC_TI85:
-    return tixx_byte2fext(TI85_CONST, TI85_MAXTYPES, data, "85?");
+    return ti85_byte2fext(data);
   case CALC_TI86:
-    return tixx_byte2fext(TI86_CONST, TI86_MAXTYPES, data, "86?");
+    return ti86_byte2fext(data);
 #endif
 #ifndef DISABLE_TI9X
   case CALC_TI89:
-    return ti89_byte2fext(data);
   case CALC_TI89T:
   case CALC_TI89T_USB:
-    return ti89t_byte2fext(data);
+    return ti89_byte2fext(data);
   case CALC_TI92:
     return ti92_byte2fext(data);
   case CALC_TI92P:
@@ -218,7 +178,7 @@ TIEXPORT2 const char *TICALL tifiles_vartype2fext(CalcModel model, uint8_t data)
   case CALC_V200:
     return v200_byte2fext(data);
   case CALC_NSPIRE:
-    return tixx_byte2fext(NSP_CONST, NSP_MAXTYPES, data, "tn?");
+    return nsp_byte2fext(data);
 #endif
   default:
     tifiles_critical("%s: invalid model argument.", __FUNCTION__);
@@ -247,38 +207,25 @@ TIEXPORT2 uint8_t TICALL tifiles_fext2vartype(CalcModel model, const char *s)
   {
 #ifndef DISABLE_TI8X
   case CALC_TI73:
-    return tixx_fext2byte(TI73_CONST, TI73_MAXTYPES, s);
+    return ti73_fext2byte(s);
   case CALC_TI82:
-    return tixx_fext2byte(TI82_CONST, TI82_MAXTYPES, s);
+    return ti82_fext2byte(s);
   case CALC_TI83:
-    return tixx_fext2byte(TI83_CONST, TI83_MAXTYPES, s);
+    return ti83_fext2byte(s);
   case CALC_TI83P:
-    return ti83p_fext2byte(s);
   case CALC_TI84P:
   case CALC_TI84P_USB:
-    return ti84p_fext2byte(s);
-  case CALC_TI82A_USB:
-    return ti82a_fext2byte(s);
-  case CALC_TI84PT_USB:
-    return ti84pt_fext2byte(s);
-  case CALC_TI84PC:
-  case CALC_TI84PC_USB:
-    return ti84pc_fext2byte(s);
-  case CALC_TI83PCE_USB:
-    return ti83pce_fext2byte(s);
-  case CALC_TI84PCE_USB:
-    return ti84pce_fext2byte(s);
+    return ti83p_fext2byte(s);
   case CALC_TI85:
-    return tixx_fext2byte(TI85_CONST, TI85_MAXTYPES, s);
+    return ti85_fext2byte(s);
   case CALC_TI86:
-    return tixx_fext2byte(TI86_CONST, TI86_MAXTYPES, s);
+    return ti86_fext2byte(s);
 #endif
 #ifndef DISABLE_TI9X
   case CALC_TI89:
-    return ti89_fext2byte(s);
   case CALC_TI89T:
   case CALC_TI89T_USB:
-    return ti89t_fext2byte(s);
+    return ti89_fext2byte(s);
   case CALC_TI92:
     return ti92_fext2byte(s);
   case CALC_TI92P:
@@ -286,7 +233,7 @@ TIEXPORT2 uint8_t TICALL tifiles_fext2vartype(CalcModel model, const char *s)
   case CALC_V200:
     return v200_fext2byte(s);
   case CALC_NSPIRE:
-    return tixx_fext2byte(NSP_CONST, NSP_MAXTYPES, s);
+    return nsp_fext2byte(s);
 #endif
   default:
     tifiles_critical("%s: invalid model argument.", __FUNCTION__);
@@ -310,38 +257,25 @@ TIEXPORT2 const char *TICALL tifiles_vartype2type(CalcModel model, uint8_t varty
   {
 #ifndef DISABLE_TI8X
   case CALC_TI73:
-    return tixx_byte2desc(TI73_CONST, TI73_MAXTYPES, vartype);
+    return ti73_byte2desc(vartype);
   case CALC_TI82:
-    return tixx_byte2desc(TI82_CONST, TI82_MAXTYPES, vartype);
+    return ti82_byte2desc(vartype);
   case CALC_TI83:
-    return tixx_byte2desc(TI83_CONST, TI83_MAXTYPES, vartype);
+    return ti83_byte2desc(vartype);
   case CALC_TI83P:
-    return ti83p_byte2desc(vartype);
   case CALC_TI84P:
   case CALC_TI84P_USB:
-    return ti84p_byte2desc(vartype);
-  case CALC_TI82A_USB:
-    return ti82a_byte2desc(vartype);
-  case CALC_TI84PT_USB:
-    return ti84pt_byte2desc(vartype);
-  case CALC_TI84PC:
-  case CALC_TI84PC_USB:
-    return ti84pc_byte2desc(vartype);
-  case CALC_TI83PCE_USB:
-    return ti83pce_byte2desc(vartype);
-  case CALC_TI84PCE_USB:
-    return ti84pce_byte2desc(vartype);
+    return ti83p_byte2desc(vartype);
   case CALC_TI85:
-    return tixx_byte2desc(TI85_CONST, TI85_MAXTYPES, vartype);
+    return ti85_byte2desc(vartype);
   case CALC_TI86:
-    return tixx_byte2desc(TI86_CONST, TI86_MAXTYPES, vartype);
+    return ti86_byte2desc(vartype);
 #endif
 #ifndef DISABLE_TI9X
   case CALC_TI89:
-    return ti89_byte2desc(vartype);
   case CALC_TI89T:
   case CALC_TI89T_USB:
-    return ti89t_byte2desc(vartype);
+    return ti89_byte2desc(vartype);
   case CALC_TI92:
     return ti92_byte2desc(vartype);
   case CALC_TI92P:
@@ -349,7 +283,7 @@ TIEXPORT2 const char *TICALL tifiles_vartype2type(CalcModel model, uint8_t varty
   case CALC_V200:
     return v200_byte2desc(vartype);
   case CALC_NSPIRE:
-    return tixx_byte2desc(NSP_CONST, NSP_MAXTYPES, vartype);
+    return nsp_byte2desc(vartype);
 #endif
   default:
     tifiles_critical("%s: invalid model argument.", __FUNCTION__);
@@ -373,38 +307,25 @@ TIEXPORT2 const char *TICALL tifiles_vartype2icon(CalcModel model, uint8_t varty
   {
 #ifndef DISABLE_TI8X
   case CALC_TI73:
-    return tixx_byte2icon(TI73_CONST, TI73_MAXTYPES, vartype);
+    return ti73_byte2icon(vartype);
   case CALC_TI82:
-    return tixx_byte2icon(TI82_CONST, TI82_MAXTYPES, vartype);
+    return ti82_byte2icon(vartype);
   case CALC_TI83:
-    return tixx_byte2icon(TI83_CONST, TI83_MAXTYPES, vartype);
+    return ti83_byte2icon(vartype);
   case CALC_TI83P:
-    return ti83p_byte2icon(vartype);
   case CALC_TI84P:
   case CALC_TI84P_USB:
-    return ti84p_byte2icon(vartype);
-  case CALC_TI82A_USB:
-    return ti82a_byte2icon(vartype);
-  case CALC_TI84PT_USB:
-    return ti84pt_byte2icon(vartype);
-  case CALC_TI84PC:
-  case CALC_TI84PC_USB:
-    return ti84pc_byte2icon(vartype);
-  case CALC_TI83PCE_USB:
-    return ti83pce_byte2icon(vartype);
-  case CALC_TI84PCE_USB:
-    return ti84pce_byte2icon(vartype);
+    return ti83p_byte2icon(vartype);
   case CALC_TI85:
-    return tixx_byte2icon(TI85_CONST, TI85_MAXTYPES, vartype);
+    return ti85_byte2icon(vartype);
   case CALC_TI86:
-    return tixx_byte2icon(TI86_CONST, TI86_MAXTYPES, vartype);
+    return ti86_byte2icon(vartype);
 #endif
 #ifndef DISABLE_TI9X
   case CALC_TI89:
-    return ti89_byte2icon(vartype);
   case CALC_TI89T:
   case CALC_TI89T_USB:
-    return ti89t_byte2icon(vartype);
+    return ti89_byte2icon(vartype);
   case CALC_TI92:
     return ti92_byte2icon(vartype);
   case CALC_TI92P:
@@ -412,7 +333,7 @@ TIEXPORT2 const char *TICALL tifiles_vartype2icon(CalcModel model, uint8_t varty
   case CALC_V200:
     return v200_byte2icon(vartype);
   case CALC_NSPIRE:
-    return tixx_byte2icon(NSP_CONST, NSP_MAXTYPES, vartype);
+    return nsp_byte2icon(vartype);
 #endif
   default:
     tifiles_critical("%s: invalid model argument.", __FUNCTION__);
@@ -424,6 +345,61 @@ TIEXPORT2 const char *TICALL tifiles_vartype2icon(CalcModel model, uint8_t varty
 /* Global types */
 /****************/
 
+static const char GROUP_FILE_EXT[CALC_MAX + 1][4] = 
+{
+	"XxX", 
+	"73g", "82g", "83g", "8Xg", "8Xg", "85g", "86g", 
+	"89g", "89g", "92g", "9Xg", "v2g", "???",
+};
+
+static const char BACKUP_FILE_EXT[CALC_MAX + 1][4] = 
+{
+	"XxX", 
+	"73b", "82b", "83b", "8Xb", "8Xb", "85b", "86b", 
+	"89g", "89g", "92b", "9Xg", "v2g", 
+	"???",
+};
+
+static const char FLASH_APP_FILE_EXT[CALC_MAX + 1][4] = 
+{
+	"XxX", 
+	"73k", "???", "???", "8Xk", "8Xk", "???", "???",
+	"89k", "89k", "???", "9Xk", "v2k", 
+	"???",
+};
+
+static const char FLASH_OS_FILE_EXT[CALC_MAX + 1][4] = 
+{
+	"XxX", 
+	"73u", "???", "???", "8Xu", "8Xu", "???", "???",
+	"89u", "89u", "???", "9Xu", "v2u", 
+	"tno",
+};
+
+static const int TIXX_DIR[CALC_MAX + 1] = 
+{
+	-1, 
+	TI73_DIR, -1, TI83_DIR, TI83p_DIR, TI84p_DIR, -1, TI86_DIR,
+	TI89_DIR, TI89_DIR, TI92_DIR, V200_DIR, 
+	NSP_DIR,
+};
+
+static const int TIXX_FLASH[CALC_MAX + 1] = 
+{
+	-1, 
+	TI73_APPL, -1, -1, TI83p_APPL, TI84p_APPL, -1, -1,
+	TI89_APPL, TI89t_APPL, -1, TI92p_APPL, V200_APPL, 
+	-1,
+};
+
+static const int TIXX_IDLIST[CALC_MAX + 1] = 
+{
+	-1, 
+	TI73_IDLIST, -1, -1, TI83p_IDLIST, TI84p_IDLIST, -1, -1,
+	TI89_IDLIST, TI89t_IDLIST, -1, TI92p_IDLIST, V200_IDLIST,
+	-1,
+};
+
 /**
  * tifiles_folder_type
  * @model: a calculator model in #CalcModel enumeration.
@@ -440,21 +416,13 @@ TIEXPORT2 uint8_t TICALL tifiles_folder_type(CalcModel model)
     return -1;
   case CALC_TI73:
     return TI73_DIR;
-  case CALC_TI80:
-    return -1;
   case CALC_TI82:
     return -1;
   case CALC_TI83:
     return TI83_DIR;
   case CALC_TI83P:
   case CALC_TI84P:
-  case CALC_TI84PC:
   case CALC_TI84P_USB:
-  case CALC_TI84PC_USB:
-  case CALC_TI83PCE_USB:
-  case CALC_TI84PCE_USB:
-  case CALC_TI82A_USB:
-  case CALC_TI84PT_USB:
     return TI83p_DIR;
   case CALC_TI85:
     return -1;
@@ -496,23 +464,14 @@ TIEXPORT2 uint8_t TICALL tifiles_flash_type(CalcModel model)
     return -1;
   case CALC_TI73:
     return TI73_APPL;
-  case CALC_TI80:
-    return -1;
   case CALC_TI82:
     return -1;
   case CALC_TI83:
     return -1;
   case CALC_TI83P:
   case CALC_TI84P:
-  case CALC_TI84PC:
   case CALC_TI84P_USB:
-  case CALC_TI84PC_USB:
-  case CALC_TI83PCE_USB:
-  case CALC_TI84PCE_USB:
     return TI83p_APPL;
-  case CALC_TI82A_USB:
-  case CALC_TI84PT_USB:
-    return -1;
   case CALC_TI85:
     return -1;
   case CALC_TI86:
@@ -553,21 +512,13 @@ TIEXPORT2 uint8_t TICALL tifiles_idlist_type(CalcModel model)
     return -1;
   case CALC_TI73:
     return TI73_IDLIST;
-  case CALC_TI80:
-    return -1;
   case CALC_TI82:
     return -1;
   case CALC_TI83:
     return -1;
   case CALC_TI83P:
   case CALC_TI84P:
-  case CALC_TI84PC:
   case CALC_TI84P_USB:
-  case CALC_TI84PC_USB:
-  case CALC_TI83PCE_USB:
-  case CALC_TI84PCE_USB:
-  case CALC_TI82A_USB:
-  case CALC_TI84PT_USB:
     return TI83p_IDLIST;
   case CALC_TI85:
     return -1;
@@ -593,9 +544,9 @@ TIEXPORT2 uint8_t TICALL tifiles_idlist_type(CalcModel model)
   return -1;
 }
 
-/*****************/
-/* Miscellaneous */
-/*****************/
+/****************/
+/* Miscelaneous */
+/****************/
 
 /**
  * tifiles_calctype2signature:
@@ -619,14 +570,9 @@ TIEXPORT2 const char *TICALL tifiles_calctype2signature(CalcModel model)
   case CALC_TI83:
     return "**TI83**";
   case CALC_TI83P:
+    return "**TI83F*";
   case CALC_TI84P:
-  case CALC_TI84PC:
   case CALC_TI84P_USB:
-  case CALC_TI84PC_USB:
-  case CALC_TI83PCE_USB:
-  case CALC_TI84PCE_USB:
-  case CALC_TI82A_USB:
-  case CALC_TI84PT_USB:
     return "**TI83F*";
   case CALC_TI85:
     return "**TI85**";
@@ -640,6 +586,7 @@ TIEXPORT2 const char *TICALL tifiles_calctype2signature(CalcModel model)
   case CALC_TI92:
     return "**TI92**";
   case CALC_TI92P:
+    return "**TI92P*";
   case CALC_V200:
     return "**TI92P*";
   case CALC_NSPIRE:
