@@ -38,20 +38,33 @@
  *
  * Return value: the entry or NULL if error.
  **/
-TIEXPORT2 VarEntry* TICALL tifiles_ve_create(void)
+TIEXPORT2 VarEntry*	TICALL tifiles_ve_create(void)
 {
 	return g_malloc0(sizeof(VarEntry));
 }
 
 /**
- * tifiles_ve_create_alloc_data:
+ * tifiles_ve_alloc_data:
+ * @size: length of data.
+ *
+ * Allocate space for data field of VarEntry.
+ *
+ * Return value: allocated space or NULL if error.
+ **/
+TIEXPORT2 void *tifiles_ve_alloc_data(size_t size)
+{
+	return g_malloc0((size+1) * sizeof(uint8_t));
+}
+
+/**
+ * tifiles_ve_create_with_data:
  * @size: length of data.
  *
  * Allocate a new VarEntry structure and space for data.
  *
  * Return value: the entry or NULL if error.
  **/
-TIEXPORT2 VarEntry* TICALL tifiles_ve_create_alloc_data(uint32_t size)
+TIEXPORT2 VarEntry*	TICALL tifiles_ve_create_with_data(uint32_t size)
 {
 	VarEntry* ve = tifiles_ve_create();
 	if (ve != NULL)
@@ -63,35 +76,32 @@ TIEXPORT2 VarEntry* TICALL tifiles_ve_create_alloc_data(uint32_t size)
 }
 
 /**
- * tifiles_ve_create_with_data:
- * @size: length of data.
+ * tifiles_ve_create_array:
+ * @nelts: size of NULL-terminated array (number of VarEntry structures).
  *
- * Deprecated version of tifiles_ve_create_alloc_data().
+ * Allocate a NULL-terminated array of VarEntry structures. You have to allocate
+ * each elements of the array by yourself.
+ *
+ * Return value: the array or NULL if error.
  **/
-TIEXPORT2 VarEntry* TICALL tifiles_ve_create_with_data(uint32_t size)
+TIEXPORT2 VarEntry**	TICALL tifiles_ve_create_array(int nelts)
 {
-	return tifiles_ve_create_alloc_data(size);
+	return g_malloc0((nelts + 1) * sizeof(VarEntry *));
 }
 
 /**
- * tifiles_ve_create_with_data2:
- * @data: data.
- * @size: length of data.
+ * tifiles_ve_resize_array:
+ * @array: address of array
+ * @nelts: size of NULL-terminated array (number of VarEntry structures).
  *
- * Allocate a new VarEntry structure and set size + data. data should have been allocated by tifiles_ve_alloc_data().
+ * Re-allocate a NULL-terminated array of VarEntry structures. You have to allocate
+ * each elements of the array by yourself.
  *
- * Return value: the entry or NULL if error.
+ * Return value: the array or NULL if error.
  **/
-TIEXPORT2 VarEntry* TICALL tifiles_ve_create_with_data2(uint32_t size, uint8_t * data)
+TIEXPORT2 VarEntry**	TICALL tifiles_ve_resize_array(VarEntry** array, int nelts)
 {
-	VarEntry* ve = tifiles_ve_create();
-	if (ve != NULL)
-	{
-		ve->data = data;
-		ve->size = size;
-	}
-
-	return ve;
+	return realloc(array, (nelts + 1) * sizeof(VarEntry *));
 }
 
 /**
@@ -102,7 +112,7 @@ TIEXPORT2 VarEntry* TICALL tifiles_ve_create_with_data2(uint32_t size, uint8_t *
  *
  * Return value: none.
  **/
-TIEXPORT2 void TICALL tifiles_ve_delete(VarEntry* ve)
+TIEXPORT2 void			TICALL tifiles_ve_delete(VarEntry* ve)
 {
 	if (ve != NULL)
 	{
@@ -115,86 +125,6 @@ TIEXPORT2 void TICALL tifiles_ve_delete(VarEntry* ve)
 	}
 }
 
-/**
- * tifiles_ve_alloc_data:
- * @size: length of data.
- *
- * Allocate space for data field of VarEntry.
- *
- * Return value: allocated space or NULL if error.
- **/
-TIEXPORT2 void * TICALL tifiles_ve_alloc_data(size_t size)
-{
-	return g_malloc0((size+1) * sizeof(uint8_t));
-}
-
-/**
- * tifiles_ve_realloc_data:
- * @size: length of data.
- *
- * Reallocate space for data field of VarEntry.
- *
- * Return value: allocated space or NULL if error.
- **/
-TIEXPORT2 VarEntry * TICALL tifiles_ve_realloc_data(VarEntry* ve, size_t size)
-{
-	if (ve != NULL)
-	{
-		uint8_t * data = g_realloc(ve->data, (size+1) * sizeof(uint8_t));
-		if (size > ve->size)
-		{
-			memset(data + ve->size, 0x00, size - ve->size);
-		}
-		ve->data = data;
-	}
-	return ve;
-}
-
-/**
- * tifiles_ve_free_data:
- * @data: length of data.
- *
- * Free space for data field of VarEntry.
- **/
-TIEXPORT2 void TICALL tifiles_ve_free_data(void * data)
-{
-	return g_free(data);
-}
-
-/**
- * tifiles_ve_create_array:
- * @nelts: size of NULL-terminated array (number of VarEntry structures).
- *
- * Allocate a NULL-terminated array of VarEntry structures. You have to allocate
- * each element of the array by yourself.
- *
- * Return value: the array or NULL if error.
- **/
-TIEXPORT2 VarEntry** TICALL tifiles_ve_create_array(unsigned int nelts)
-{
-	return g_malloc0((nelts + 1) * sizeof(VarEntry *));
-}
-
-/**
- * tifiles_ve_resize_array:
- * @array: address of array
- * @nelts: size of NULL-terminated array (number of VarEntry structures).
- *
- * Re-allocate a NULL-terminated array of VarEntry structures. You have to allocate
- * each element of the array by yourself.
- *
- * Return value: the array or NULL if error.
- **/
-TIEXPORT2 VarEntry** TICALL tifiles_ve_resize_array(VarEntry** array, unsigned int nelts)
-{
-	VarEntry ** ptr = g_realloc(array, (nelts + 1) * sizeof(VarEntry *));
-	if (ptr != NULL)
-	{
-		ptr[nelts] = NULL;
-	}
-	return ptr;
-}
-
 /**
  * tifiles_ve_delete_array:
  * @array: an NULL-terminated array of VarEntry structures.
@@ -203,16 +133,14 @@ TIEXPORT2 VarEntry** TICALL tifiles_ve_resize_array(VarEntry** array, unsigned i
  *
  * Return value: none.
  **/
-TIEXPORT2 void TICALL tifiles_ve_delete_array(VarEntry** array)
+TIEXPORT2 void			TICALL tifiles_ve_delete_array(VarEntry** array)
 {
 	VarEntry** ptr;
 
 	if (array != NULL)
 	{
-		for (ptr = array; *ptr; ptr++)
-		{
+		for(ptr = array; ptr; ptr++)
 			tifiles_ve_delete(*ptr);
-		}
 		g_free(array);
 	}
 	else
@@ -231,7 +159,7 @@ TIEXPORT2 void TICALL tifiles_ve_delete_array(VarEntry** array)
  *
  * Return value: the dst pointer or NULL if malloc error.
  **/
-TIEXPORT2 VarEntry* TICALL tifiles_ve_copy(VarEntry* dst, VarEntry* src)
+TIEXPORT2 VarEntry*	TICALL tifiles_ve_copy(VarEntry* dst, VarEntry* src)
 {
 	int alloc;
 
@@ -265,7 +193,7 @@ TIEXPORT2 VarEntry* TICALL tifiles_ve_copy(VarEntry* dst, VarEntry* src)
  *
  * Return value: a newly allocated entry (must be freed with #tifiles_ve_delete when no longer needed).
  **/
-TIEXPORT2 VarEntry* TICALL tifiles_ve_dup(VarEntry* src)
+TIEXPORT2 VarEntry*	TICALL tifiles_ve_dup(VarEntry* src)
 {
 	VarEntry* dst = NULL;
 
@@ -277,7 +205,7 @@ TIEXPORT2 VarEntry* TICALL tifiles_ve_dup(VarEntry* src)
 			memcpy(dst, src, sizeof(VarEntry));
 			dst->data = (uint8_t *)g_malloc0(dst->size);
 
-			if (src->data != NULL && dst->data != NULL)
+			if(src->data != NULL && dst->data != NULL)
 			{
 				memcpy(dst->data, src->data, dst->size);
 			}
@@ -300,7 +228,7 @@ TIEXPORT2 VarEntry* TICALL tifiles_ve_dup(VarEntry* src)
  *
  * Return value: the entry or NULL if error.
  **/
-TIEXPORT2 FlashPage* TICALL tifiles_fp_create(void)
+TIEXPORT2 FlashPage*	TICALL tifiles_fp_create(void)
 {
 	return g_malloc0(sizeof(FlashPage));
 }
@@ -313,7 +241,7 @@ TIEXPORT2 FlashPage* TICALL tifiles_fp_create(void)
  *
  * Return value: allocated space or NULL if error.
  **/
-TIEXPORT2 void * TICALL tifiles_fp_alloc_data(size_t size)
+TIEXPORT2 void *tifiles_fp_alloc_data(size_t size)
 {
 	uint8_t *data;
 
@@ -327,47 +255,14 @@ TIEXPORT2 void * TICALL tifiles_fp_alloc_data(size_t size)
 }
 
 /**
- * tifiles_fp_realloc_data:
- * @size: new length of data.
- *
- * Reallocate space for data field of FlashPage.
- *
- * Return value: flash page, or NULL if error.
- **/
-TIEXPORT2 FlashPage * TICALL tifiles_fp_realloc_data(FlashPage* fp, size_t size)
-{
-	if (fp != NULL)
-	{
-		uint8_t * data = g_realloc(fp->data, (size+1) * sizeof(uint8_t));
-		if (size > fp->size)
-		{
-			memset(data + fp->size, 0xFF, size - fp->size);
-		}
-		fp->data = data;
-	}
-	return fp;
-}
-
-/**
- * tifiles_fp_free_data:
- * @data: length of data.
- *
- * Free space for data field of FlashPage.
- **/
-TIEXPORT2 void TICALL tifiles_fp_free_data(void * data)
-{
-	return g_free(data);
-}
-
-/**
- * tifiles_fp_create_alloc_data:
+ * tifiles_fp_create_with_data:
  * @size: length of data.
  *
  * Allocate a new FlashPage structure and space for data.
  *
  * Return value: the entry or NULL if error.
  **/
-TIEXPORT2 FlashPage* TICALL tifiles_fp_create_alloc_data(uint32_t size)
+TIEXPORT2 FlashPage*	TICALL tifiles_fp_create_with_data(uint32_t size)
 {
 	FlashPage* ve = tifiles_fp_create();
 	if (ve != NULL)
@@ -378,72 +273,20 @@ TIEXPORT2 FlashPage* TICALL tifiles_fp_create_alloc_data(uint32_t size)
 	return ve;
 }
 
-/**
- * tifiles_fp_create_alloc_data:
- * @size: length of data.
- *
- * Deprecated version of tifiles_ve_create_alloc_data().
- **/
-TIEXPORT2 FlashPage* TICALL tifiles_fp_create_with_data(uint32_t size)
-{
-	return tifiles_fp_create_alloc_data(size);
-}
-
-/**
- * tifiles_fp_create_with_data2:
- * @data: data.
- * @size: length of data.
- *
- * Allocate a new FlashPage structure and set size + data. data should have been allocated by tifiles_fp_alloc_data().
- *
- * Return value: the entry or NULL if error.
- **/
-TIEXPORT2 FlashPage* TICALL tifiles_fp_create_with_data2(uint32_t size, uint8_t * data)
-{
-	FlashPage* ve = tifiles_fp_create();
-	if (ve != NULL)
-	{
-		ve->data = data;
-		ve->size = size;
-	}
-
-	return ve;
-}
-
 /**
  * tifiles_fp_create_array:
  * @nelts: size of NULL-terminated array (number of FlashPage structures).
  *
  * Allocate a NULL-terminated array of FlashPage structures. You have to allocate
- * each element of the array by yourself.
+ * each elements of the array by yourself.
  *
  * Return value: the array or NULL if error.
  **/
-TIEXPORT2 FlashPage** TICALL tifiles_fp_create_array(unsigned int nelts)
+TIEXPORT2 FlashPage**	TICALL tifiles_fp_create_array(int nelts)
 {
 	return g_malloc0((nelts + 1) * sizeof(FlashPage*));
 }
 
-/**
- * tifiles_fp_resize_array:
- * @array: address of array
- * @nelts: size of NULL-terminated array (number of FlashPage structures).
- *
- * Re-allocate a NULL-terminated array of FlashPage structures. You have to allocate
- * each element of the array by yourself.
- *
- * Return value: the array or NULL if error.
- **/
-TIEXPORT2 FlashPage** TICALL tifiles_fp_resize_array(FlashPage** array, unsigned int nelts)
-{
-	FlashPage ** ptr = g_realloc(array, (nelts + 1) * sizeof(FlashPage *));
-	if (ptr != NULL)
-	{
-		ptr[nelts] = NULL;
-	}
-	return ptr;
-}
-
 /**
  * tifiles_fp_delete:
  * @ve: var entry.
@@ -452,7 +295,7 @@ TIEXPORT2 FlashPage** TICALL tifiles_fp_resize_array(FlashPage** array, unsigned
  *
  * Return value: none.
  **/
-TIEXPORT2 void TICALL tifiles_fp_delete(FlashPage* fp)
+TIEXPORT2 void			TICALL tifiles_fp_delete(FlashPage* fp)
 {
 	if (fp != NULL)
 	{
@@ -473,16 +316,14 @@ TIEXPORT2 void TICALL tifiles_fp_delete(FlashPage* fp)
  *
  * Return value: none.
  **/
-TIEXPORT2 void TICALL tifiles_fp_delete_array(FlashPage** array)
+TIEXPORT2 void			TICALL tifiles_fp_delete_array(FlashPage** array)
 {
 	FlashPage** ptr;
 
 	if (array != NULL)
 	{
-		for (ptr = array; *ptr; ptr++)
-		{
+		for(ptr = array; ptr; ptr++)
 			tifiles_fp_delete(*ptr);
-		}
 		g_free(array);
 	}
 	else
